//
//  GetAnuncios.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 16/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import FirebaseFirestore
import SwiftUI

class GetAnuncios:ObservableObject{
    
    private var empresaID: String = UserDefaults.standard.object(forKey: "EmpresaID") as! String

    @Published var anuncios = [Anuncio]()
  
    init(){
        obtenAnuncios()
    }
    
    //Función para obtener los anuncios de la empresa del usuario registrado
    func obtenAnuncios(){
        
        let db = Firestore.firestore()
        // creamos referencia a la coleccion de anuncios
        let ref = db.collection("empresas").document(self.empresaID).collection("anuncios").order(by: "fecha", descending: true)
        // creamos un listener para actualizar la lista de anuncios cuando estos cambien
        ref.addSnapshotListener{ (anuncios,error) in
            if error != nil{
                print("Error")
            }else{
                self.anuncios.removeAll()
                for anuncio in anuncios!.documents{
                    
                    let id = anuncio.documentID
                    let titulo = anuncio.data()["titulo"] as? String ?? ""
                    let usuario = anuncio.data()["usuario"] as? String ?? ""
                    let fecha = anuncio.data()["fecha"] as? Timestamp ?? Timestamp(date: Date())
                    let prioridad = anuncio.data()["prioridad"] as? Int ?? 0
                    let anuncio = anuncio.data()["anuncio"] as? String ?? ""
                   
                    DispatchQueue.main.async {
                        let registro = Anuncio(id: id, titulo:titulo, usuario:usuario, fecha: fecha.dateValue(), prioridad: prioridad, anuncio: anuncio)
                    self.anuncios.append(registro)
                    }
                }
            }
            
        }
    }
    
    
}
