//
//  GetAusencias.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 21/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import FirebaseFirestore
import SwiftUI

class GetAusencias:ObservableObject{
    
    private let empresaID: String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    private var usuario:String = UserDefaults.standard.object(forKey: "UserMail") as! String
    private let isAdmin: Bool = UserDefaults.standard.bool(forKey: "isAdmin")
    
    @Published var ausencias = [Ausencia]()
    
    init(){
        
        if self.isAdmin{
            obtenAusenciasUsers()
        }else{
            obtenAusenciasUser()
        }
        
    }
    
    //Función para obtener las ausencias del usuario registrado
    func obtenAusenciasUser(){
        
        let db = Firestore.firestore()
        // creamos referencia al usuario registrado
        let doc = db.collection("empresas").document(self.empresaID).collection("users").whereField("mail", isEqualTo: self.usuario)
        doc.getDocuments(){ (usuarios,error) in
            if error != nil{
                print("error: \(String(describing: error?.localizedDescription))")
            }else{
                for documento in usuarios!.documents{
                    // creamos referencia a su coleccion de ausencias y creamos el listener
                    let ref = db.collection("empresas").document(self.empresaID).collection("users").document(documento.documentID).collection("ausencias")
                    ref.addSnapshotListener{ (ausencias,error) in
                        if error != nil{
                            print("error: \(String(describing: error?.localizedDescription))")
                        }else{
                            self.ausencias.removeAll() //limpiamos la lista antes de que se actualice después de un evento
                            for ausencia in ausencias!.documents{
                                
                                let user = documento.data()["nombre"] as? String ?? ""
                                
                                let id = ausencia.documentID
                                let tipo = ausencia.data()["tipo"] as? String ?? ""
                                let inicio = ausencia.data()["inicio"] as? Timestamp ?? Timestamp(date: Date())
                                let final = ausencia.data()["final"] as? Timestamp ?? Timestamp(date: Date())
                                let adjunto = ausencia.data()["adjunto"] as? String ?? ""
                                let estado = ausencia.data()["estado"] as? String ?? ""
                                let mensaje = ausencia.data()["mensaje"] as? String ?? ""
                                
                                DispatchQueue.main.async {
                                    let registro = Ausencia(id: id, tipo: tipo, inicio: inicio.dateValue(), fin: final.dateValue(), adjunto: adjunto, estado: estado, observaciones: mensaje,user: user,userID: self.usuario)
                                    self.ausencias.append(registro)
                                }
                            }
                        }
                        
                    }
                }
            }
            
        }
        
    }
    
    //Función para obtener las ausencias de todos los usuarios de la empresa menos el registrado
    func obtenAusenciasUsers(){
        
        let db = Firestore.firestore()
        // creamos referencia a los usuarios de la empresa
        let doc = db.collection("empresas").document(self.empresaID).collection("users")
        doc.getDocuments(){ (usuarios,error) in
            if error != nil{
                print("error: \(String(describing: error?.localizedDescription))")
            }else{
                for documento in usuarios!.documents{
                    // creamos referencia a su coleccion de ausencias y creamos el listener
                    let ref = doc.document(documento.documentID).collection("ausencias")
                    ref.addSnapshotListener{ (ausencias,err) in
                        //limpiamos las ausencias de un usuario concreto de la tabla antes de actualizarla (tenemos un listener por cada usuario)
                        for old in self.ausencias{
                            let mail = documento.data()["mail"] as! String
                            if old.userID.isEqual(mail){
                                self.ausencias.remove(at: self.ausencias.firstIndex(of: old)!)
                            }
                        } //limpiamos la lista antes de que se actualice después de un evento
                        if err != nil{
                            print("error: \(String(describing: error?.localizedDescription))")
                        }else{
                            
                            for ausencia in ausencias!.documents{
                                
                                let user = documento.data()["nombre"] as? String ?? ""
                                let userMail = documento.data()["mail"] as? String ?? ""
                                    
                                    let id = ausencia.documentID
                                    let tipo = ausencia.data()["tipo"] as? String ?? ""
                                    let inicio = ausencia.data()["inicio"] as? Timestamp ?? Timestamp(date: Date())
                                    let final = ausencia.data()["final"] as? Timestamp ?? Timestamp(date: Date())
                                    let adjunto = ausencia.data()["adjunto"] as? String ?? ""
                                    let estado = ausencia.data()["estado"] as? String ?? ""
                                    let mensaje = ausencia.data()["mensaje"] as? String ?? ""
                                    
                                    DispatchQueue.main.async {
                                        let registro = Ausencia(id: id, tipo: tipo, inicio: inicio.dateValue(), fin: final.dateValue(), adjunto: adjunto, estado: estado, observaciones: mensaje,user: user,userID: userMail)
                                        self.ausencias.append(registro)
                                    }
                                }
                            }
                            
                        }
                    }
                }
                
        }
        
    }
}
