//
//  GetDescansos.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 29/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import FirebaseFirestore
import SwiftUI

class GetDescansos:ObservableObject{
    
    private let empresaID: String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    private var usuario:String = ""
    private let isAdmin: Bool = UserDefaults.standard.bool(forKey: "isAdmin")

    @Published var descansos = [Descanso]()
    
    init(user: String, dia:String){
        self.usuario = user
        self.obtenDescansosJornada(dia: dia)
    }
    
    //Función para obtener las jornadas del usuario registrado y sus descansos correspondientes
    func obtenDescansosJornada(dia: String){
        
        let db = Firestore.firestore()
        // creamos referencia a las jornadas del usuario
        let ref = db.collection("empresas").document(self.empresaID).collection("users").document(self.usuario).collection("jornadas").document(dia).collection("descansos").order(by: "inicio", descending: true)
        ref.addSnapshotListener{ (descansos,error) in
            if error != nil{
                print("error: \(String(describing: error?.localizedDescription))")
            }else{
                self.descansos.removeAll() //limpiamos la lista antes de que se actualice después de un evento
                
                for descanso in descansos!.documents{
                    let id = descanso.documentID
                    let inicio = descanso.data()["inicio"] as? Timestamp ?? Timestamp(date: Date())
                    let fin = descanso.data()["fin"] as? Timestamp ?? inicio
                    
                    
                    DispatchQueue.main.async {
                        
                        let registro = Descanso(id: id, inicio: inicio.dateValue() , fin: fin.dateValue())
                        self.descansos.append(registro)
                    }
                }
            }
            
            
        }
        
        
    }
    
    //Función que devuelve una cadena con las horas:minutos:segundos de un intervalo de tiempo recibido como parámetro
        func obtenTiempos(tiempo: Double) -> String{
            
            let intervalo = tiempo
            
            var horas = 0
            var minutos = 0
            var segundos = 0
            var StrMinutos = "00"
            var StrSegundos = "00"
            
            if intervalo < 60{
                horas = 0
                minutos = 0
                segundos = Int(intervalo)
            }else if intervalo >= 60 && intervalo < 3600{
                horas = 0
                minutos = Int(intervalo/60)
                segundos = Int(intervalo.truncatingRemainder(dividingBy: 60))
            }else{
                horas = Int(intervalo/3600)
                let resto = intervalo.truncatingRemainder(dividingBy: 3600)
                minutos = Int(resto/60)
                segundos = Int(resto.truncatingRemainder(dividingBy: 60))
            }
            if minutos < 10 {
                StrMinutos = "0\(minutos)"
            }else{
                StrMinutos = "\(minutos)"
            }
            if segundos < 10 {
                StrSegundos = "0\(segundos)"
            }else{
                StrSegundos = "\(segundos)"
            }
            
            return ("\(horas):\(StrMinutos):\(StrSegundos)")
        }
  
}


