//
//  GetJornadas.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 29/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import FirebaseFirestore
import SwiftUI

class GetJornadas:ObservableObject{
    
    private let empresaID: String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    private var usuario:String = UserDefaults.standard.object(forKey: "UserID") as! String
    private let isAdmin: Bool = UserDefaults.standard.bool(forKey: "isAdmin")
    
    @Published var meses = [String]()
    @Published var jornadas = [Dia]()
   
    init(){
        self.obtenJornadasUser()
    }
    init(user: String){
        self.usuario = user
        self.obtenJornadasUser()
    }
    
      
      //Función para obtener un String con el mes de una determinada fecha
      private func getDate(date:Date)->String{
          let format = DateFormatter()
          format.dateFormat = "MMMM yyyy"
          let year = format.string(from: date)
          return year
      }
    
    
    //Función para obtener las jornadas del usuario registrado y sus descansos correspondientes
    func obtenJornadasUser(){
        self.meses.append("Todos los meses")
        
        let db = Firestore.firestore()
        // creamos referencia a las jornadas del usuario
        let ref = db.collection("empresas").document(self.empresaID).collection("users").document(self.usuario).collection("jornadas").order(by: "inicio", descending: true)
        ref.addSnapshotListener{ (jornadas,error) in
            if error != nil{
                print("error: \(String(describing: error?.localizedDescription))")
            }else{
                self.jornadas.removeAll() //limpiamos la lista antes de que se actualice después de un evento
                for jornada in jornadas!.documents{
                    
                    let id = jornada.documentID
                    let inicio = jornada.data()["inicio"] as? Timestamp ?? Timestamp(date: Date())
                    let fin = jornada.data()["fin"] as? Timestamp ?? inicio
                    let locInicio = jornada.data()["locInicio"] as? String ?? ""
                    let locFin = jornada.data()["locFin"] as? String ?? ""
                    let totalDescansos = jornada.data()["totalDescansos"] as? Double ?? 0
                  
                    DispatchQueue.main.async {
                        let registro = Dia(id: id, inicio: inicio.dateValue(), fin: fin.dateValue(), locInicio: locInicio, locFin: locFin, totalDescansosDia: totalDescansos)
                        self.jornadas.append(registro)
                        }
                    let mes = self.getDate(date: inicio.dateValue())
                    if !self.meses.contains(mes){
                        self.meses.append(mes)
                    }
                }
                }
          
            }
        
        }
    
    //Función que devuelve una cadena con las horas:minutos:segundos de un intervalo de tiempo recibido como parámetro
    func obtenTiempos(tiempo: Double) -> String{
        
        let intervalo = tiempo
        
        var horas = 0
        var minutos = 0
        var segundos = 0
        var StrMinutos = "00"
        var StrSegundos = "00"
        
        if intervalo < 60{
            horas = 0
            minutos = 0
            segundos = Int(intervalo)
        }else if intervalo >= 60 && intervalo < 3600{
            horas = 0
            minutos = Int(intervalo/60)
            segundos = Int(intervalo.truncatingRemainder(dividingBy: 60))
        }else{
            horas = Int(intervalo/3600)
            let resto = intervalo.truncatingRemainder(dividingBy: 3600)
            minutos = Int(resto/60)
            segundos = Int(resto.truncatingRemainder(dividingBy: 60))
        }
        if minutos < 10 {
            StrMinutos = "0\(minutos)"
        }else{
            StrMinutos = "\(minutos)"
        }
        if segundos < 10 {
            StrSegundos = "0\(segundos)"
        }else{
            StrSegundos = "\(segundos)"
        }
        
        return ("\(horas):\(StrMinutos):\(StrSegundos)")
    }

}
