//
//  GetLocalizacion.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 26/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import CoreLocation

class GetLocalizacion: NSObject, ObservableObject{ //NSObject nos permitirá implementar el CLLocationManagerDelegate
    
    @Published var showAlert: Bool = false
    
    @Published var latitude: Double = 0
    @Published var longitude: Double = 0
    @Published var direccion: String = ""
    @Published var localidad: String = ""
    @Published var pais:String=""
    
    private let locationManager = CLLocationManager() //Protocolo
    
    override init() {
        super.init()
        self.locationManager.delegate = self //Asignamos esta clase como delegado de implementar el protocolo
        self.locationManager.desiredAccuracy = kCLLocationAccuracyBest
        self.locationManager.requestWhenInUseAuthorization()
        self.locationManager.startUpdatingLocation()
    }
}

extension GetLocalizacion: CLLocationManagerDelegate { //desarrollamos las funciones necesarias del protocolo
    
    //Función para gestionar una autorización denegada de la ubicación por parte del usuario
    func locationManager(_ manager: CLLocationManager, didChangeAuthorization status: CLAuthorizationStatus) {
        if status == .denied {
            self.showAlert.toggle()
        }
    }
    func locationManager(_ manager: CLLocationManager, didUpdateLocations locations: [CLLocation]) {
        guard let location = locations.last else { return }
        self.latitude = location.coordinate.latitude
        self.longitude = location.coordinate.longitude
        let geocoder = CLGeocoder()
        geocoder.reverseGeocodeLocation(location) { (place, error) in
            if error != nil {
                print((error?.localizedDescription)!)
                return
            }
            //let place = place?.first?.locality
            let direccion = place?.first?.name
            let localidad = place?.first?.locality
            let codigo = place?.first?.postalCode
            let pais = place?.first?.country
            self.direccion = ("\(direccion ?? "")")
            self.localidad = ("\(codigo ?? "") (\(localidad ?? ""))")
            self.pais = ("\(pais ?? "")")
        }
    }
}
