//
//  GetProyectos.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 19/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import FirebaseFirestore
import SwiftUI

class GetProyectos:ObservableObject{
    
    private var empresaID: String = ""

    @Published var proyectos = [Proyecto]()
    @Published var years = [String]()
    
  
    init(empresa: String){
        self.empresaID = empresa
        obtenProyectos()
    }
    
    //Función para obtener un String con el año de una determinada fecha
    private func getYear(date:Date)->String{
        let format = DateFormatter()
        format.dateFormat = "yyyy"
        let year = format.string(from: date)
        return year
    }
    //Función para obtener los anuncios de la empresa del usuario registrado
    func obtenProyectos(){
        self.years.append("Todos los años")
        
        let db = Firestore.firestore()
        // creamos referencia a la coleccion de proyectos
        let ref = db.collection("empresas").document(self.empresaID).collection("proyectos").order(by: "inicio", descending: true)
        // creamos un listener para actualizar la lista de proyectos cuando estos cambien
        ref.addSnapshotListener{ (proyectos,error) in
            if error != nil{
                print("Error")
            }else{
                self.proyectos.removeAll()
                for proyecto in proyectos!.documents{
                    
                    
                    let id = proyecto.documentID
                    let nombre = proyecto.data()["nombre"] as? String ?? ""
                    let cliente = proyecto.data()["cliente"] as? String ?? ""
                    let responsable = proyecto.data()["responsable"] as? String ?? ""
                    let inicio = proyecto.data()["inicio"] as? Timestamp ?? Timestamp(date: Date())
                    let entrega = proyecto.data()["entrega"] as? Timestamp ?? Timestamp(date: Date())
                    let estado = proyecto.data()["estado"] as? String ?? ""
                    let mensaje = proyecto.data()["mensaje"] as? String ?? ""

                    DispatchQueue.main.async {
                        let registro = Proyecto(id: id, nombre: nombre, cliente: cliente, responsable: responsable, inicio: inicio.dateValue(), entrega: entrega.dateValue(), estado: estado, mensaje: mensaje)
                        self.proyectos.append(registro)
                    }
                    
                    let year = self.getYear(date: inicio.dateValue())
                    if !self.years.contains(year){
                        self.years.append(year)
                    }
                    
                }
            }
            
        }
    }
}
