//
//  Jornada.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 25/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import Foundation
import Combine
import SwiftUI
import FirebaseFirestore
import MapKit

class Jornada:ObservableObject{
    
    private var timerHoy: Timer = Timer()
    
    private var tiempoJornada: Double = 0
    var tiempoDescanso: Double = 0
    private var descansoJornada: Double = 0
    private var jornadaID: String = ""
    private var descansoID : String = ""
//    private var empresa:String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
//    private var usuario:String = UserDefaults.standard.object(forKey: "UserID") as! String
    
    @ObservedObject var localizacion = GetLocalizacion()
    
    @Published var textAlert:String = ""
    @Published var showAlert:Bool = false
    
    @Published var isStarted: Bool = false
    @Published var isPaused: Bool = false
    
    @Published var place: String = ""
    @Published var direccion: String = "-"
    @Published var localidad: String = "-"
    
    @Published var now: Date = Date()
    @Published var inicio: Date = Date()
    @Published var fichaje: String = "0:00:00"
    @Published var final: Date = Date()
    @Published var inicioDescanso: Date = Date()
    @Published var finDescanso: Date = Date()
    
    @Published var tiempoDesdeInicio: String = "00:00:00"
    
    init(){
        self.timerHoy = Timer.scheduledTimer(withTimeInterval: 1, repeats: true){ (timer) in
            self.now = Date()
            if self.isStarted{
                self.final = Date()
                if self.isPaused{
                    self.finDescanso = Date()
                }
            }
        }
    }
    //Funciones para la temporización
    func empezarDia(isGPS:Bool){
        let format = DateFormatter()
        format.dateFormat = "HH:mm:ss"
        if isGPS{
            obtenLocalizacion()
        }else{
            self.direccion = UserDefaults.standard.object(forKey: "Empresa") as! String
            self.localidad = "QR Code"
             self.place = ("\(self.direccion) (QRCode)")
        }
        self.tiempoJornada = self.tiempoJornada + self.inicio.distance(to:self.final) //acumulamos el descanso anterior
        self.fichaje = format.string(from: Date())
        self.inicio = Date()
        self.final = Date()
        self.isStarted = true
        UserDefaults.standard.set(true, forKey: "isStarted")
        self.registrarInicioJornada()
        
    }

    func finalizarDia(isGPS: Bool){ //parametro para diferenciar entre la pausa y el final
        self.isPaused = false
        self.isStarted = false
        if isGPS{
            obtenLocalizacion()
        }else{
            self.direccion = UserDefaults.standard.object(forKey: "Empresa") as! String
            self.localidad = "QR Code"
            self.place = ("\(self.direccion) (QRCode)")
        }
        if self.jornadaID.isEmpty{
            self.textAlert = "Error: No se ha podido registrar el final de su jornada. Compruebe su conexión"
            self.showAlert.toggle()
            print("Fallo")
        }else{
            self.registrarFinalJornada()
        }
        self.inicio = Date()
        self.final = Date()
        self.inicioDescanso = Date()
        self.finDescanso = Date()
        self.fichaje = "0:00:00"
        self.tiempoJornada = 0
        self.tiempoDescanso = 0
        self.descansoJornada = 0
        self.direccion = "-"
        self.localidad = "-"
        UserDefaults.standard.set(false, forKey: "isStarted")
    }
    
    func empezarDescanso(){
        self.tiempoDescanso = self.tiempoDescanso + self.inicioDescanso.distance(to:self.finDescanso) //acumulamos el descanso anterior
        self.inicioDescanso = Date()
        self.finDescanso = Date()
        self.isPaused = true
        self.registrarInicioDescanso()
        
    }
    
    func finalizarDescanso(){
        self.descansoJornada = self.descansoJornada + self.inicioDescanso.distance(to: self.finDescanso)
        self.isPaused = false
        if self.descansoID.isEmpty{
            self.textAlert = "Error: No se ha podido registrar el final de su descanso. Compruebe su conexión"
            self.showAlert.toggle()
            print("Fallo")
        }else{
        self.registrarFinalDescanso()
        }
    }
    
    //Registros de jornada y descansos en la base de datos
    func registrarInicioJornada(){
        var ref:DocumentReference? = nil
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["inicio":self.inicio, "fin": "", "locInicio": self.place, "locFin":""]
        ref = db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("users").document(UserDefaults.standard.object(forKey: "UserID") as! String).collection("jornadas").addDocument(data: campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir la jornada a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.jornadaID = ref!.documentID
            }
        }
    }
    
    func registrarFinalJornada(){
        let db = Firestore.firestore()
        let campos : [String: Any] = ["fin": self.final, "locFin":self.place, "totalDescansos": self.descansoJornada]
        db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("users").document(UserDefaults.standard.object(forKey: "UserID") as! String).collection("jornadas").document(self.jornadaID).updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir la jornada a la base de datos!"
                self.showAlert.toggle()
            }
        }
    }
    
    func registrarInicioDescanso(){
        var ref:DocumentReference? = nil
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["inicio":self.inicioDescanso, "fin": ""]
        let doc = db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("users").document(UserDefaults.standard.object(forKey: "UserID") as! String).collection("jornadas")
        ref = doc.document(self.jornadaID).collection("descansos").addDocument(data: campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir la jornada a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.descansoID = ref!.documentID
            }
            
        }
    }
    
    func registrarFinalDescanso(){
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["fin": self.finDescanso]
        db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("users").document(UserDefaults.standard.object(forKey: "UserID") as! String).collection("jornadas").document(self.jornadaID).collection("descansos").document(self.descansoID).updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir la jornada a la base de datos!"
                self.showAlert.toggle()
            }
        }
    }
    
    //Utilidades
    //Devuelve un string con la diferencia entre dos fechas en formato h:mm:ss(full) o h:mm
    func obtenDiferencia(desde:Date, hasta: Date, full: Bool, isDescanso: Bool) -> String{
        var intervalo:Double = 0
        
        if isDescanso{
            intervalo = self.tiempoDescanso.rounded() + desde.distance(to: hasta).rounded() //utilizamos el tiempo de descanso acumulado
        }else{
            intervalo = desde.distance(to: hasta).rounded()
        }
        
        var horas = 0
        var minutos = 0
        var segundos = 0
        var StrMinutos = "00"
        var StrSegundos = "00"
        
        if intervalo < 60{
            horas = 0
            minutos = 0
            segundos = Int(intervalo)
        }else if intervalo >= 60 && intervalo < 3600{
            horas = 0
            minutos = Int(intervalo/60)
            segundos = Int(intervalo.truncatingRemainder(dividingBy: 60))
        }else{
            horas = Int(intervalo/3600)
            let resto = intervalo.truncatingRemainder(dividingBy: 3600)
            minutos = Int(resto/60)
            segundos = Int(resto.truncatingRemainder(dividingBy: 60))
        }
        if minutos < 10 {
            StrMinutos = "0\(minutos)"
        }else{
            StrMinutos = "\(minutos)"
        }
        if segundos < 10 {
            StrSegundos = "0\(segundos)"
        }else{
            StrSegundos = "\(segundos)"
        }
        
        if full{
            return ("\(horas):\(StrMinutos):\(StrSegundos)")
            
        }else{
            return ("\(horas):\(StrMinutos)")
            
        }
        
    }
    
    //Devuelve un string con el tiempo total transcurrido (trabajado + descanso) en formato h:mm:ss(full) o h:mm
    func obtenTotalTrabajado(full: Bool) -> String{
        
        let intervaloDia = self.inicio.distance(to: self.final).rounded()
        let intervaloDescanso = self.tiempoDescanso.rounded() + self.inicioDescanso.distance(to: self.finDescanso).rounded() //utilizamos el tiempo de descanso acumulado
        let intervalo = intervaloDia - intervaloDescanso
        var horas = 0
        var minutos = 0
        var segundos = 0
        var StrMinutos = "00"
        var StrSegundos = "00"
        
        if intervalo < 60{
            horas = 0
            minutos = 0
            segundos = Int(intervalo)
        }else if intervalo >= 60 && intervalo < 3600{
            horas = 0
            minutos = Int(intervalo/60)
            segundos = Int(intervalo.truncatingRemainder(dividingBy: 60))
        }else{
            horas = Int(intervalo/3600)
            let resto = intervalo.truncatingRemainder(dividingBy: 3600)
            minutos = Int(resto/60)
            segundos = Int(resto.truncatingRemainder(dividingBy: 60))
        }
        if minutos < 10 {
            StrMinutos = "0\(minutos)"
        }else{
            StrMinutos = "\(minutos)"
        }
        if segundos < 10 {
            StrSegundos = "0\(segundos)"
        }else{
            StrSegundos = "\(segundos)"
        }
        if full{
            return ("\(horas):\(StrMinutos):\(StrSegundos)")
            
        }else{
            return ("\(horas):\(StrMinutos)")
            
        }
        
    }

    //Datos Localizacion
    func obtenLocalizacion(){
        self.place = self.localizacion.direccion + "," + self.localizacion.localidad + "," + self.localizacion.pais
        self.direccion = self.localizacion.direccion
        self.localidad = self.localizacion.localidad + "," + self.localizacion.pais
    }
    
}























