//
//  LoginView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 19/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseAuth

struct LoginView: View {
    
    @State private var username: String = ""
    @State private var password: String = ""
    @State private var showReg: Bool = false
    @State private var showHome: Bool = false
    @State private var showRecovery: Bool = false
    @State private var isError: Bool = false
    @State private var messError: String = ""
    @State private var offsetTeclado: CGFloat = 0
    
    var body: some View {
        
        ZStack{
            NavigationLink(destination: RegisterView(show: self.$showReg), isActive: self.$showReg){
                EmptyView()
            }
            NavigationLink(destination: HomeView(), isActive: self.$showHome){
               EmptyView()
            }
            NavigationLink(destination: RecoveryPassView(showLogin: self.$showRecovery), isActive: self.$showRecovery){
               EmptyView()
            }
            VStack{
                //Logo
                VStack{
                    ZStack{
                        
                        Circle().foregroundColor(Color("ColorLogo"))
                            .frame(width: 180, height: 180)
                            .shadow(radius: 30)
                        Circle().foregroundColor(Color("Fondo"))
                            .frame(width: 150, height: 150)
                        
                        Image("gear1").resizable().foregroundColor(.black)
                            .frame(width: 80, height: 80)
                            .offset(x: 20, y: -40)
                        
                        Image("logo1").resizable().foregroundColor(.black)
                            .frame(width: 180, height: 150)
                        
                        
                    }
                    Text("ControlWork")
                        .font(.largeTitle)
                        .bold().offset(y:-20)
                    
                    
                }.padding(.top,10)
                
                //Login
                VStack (spacing: 20){
                    
                    Text("Bienvenidos")
                        .font(.title)
                        .fontWeight(.bold)
                        .padding(.bottom)
                    
                    if isError{
                        Text(messError)
                            .foregroundColor(.red)
                    }else{
                        Text("") //mantenemos el formato
                    }
                    
                    
                    FieldLoginView(texto: self.$username, isEmail: true)
                    FieldLoginView(texto: self.$password, isPass: true)
                    
                    HStack{
                        Spacer()
                        Button(action:{
                            self.showRecovery.toggle()
                        }){
                            Text("¿No puedes entrar?")
                                .padding(.trailing,20)
                                .font(.subheadline)
                                
                        }
                        
                    }
                    
                    Button(action: {
                        self.isError = false
                        Auth.auth().signIn(withEmail: self.username, password: self.password){ (user, error) in
                            if user != nil{
                                self.showHome = true
                                UserDefaults.standard.set(self.username, forKey: "UserMail")
                            }else{
                                if let error = error?.localizedDescription{
                                    if error.contains("password"){
                                        self.messError = "Password incorrecto"
                                        //print ("password incorrecto", error)
                                    }else if error.contains("Network"){
                                         self.messError = "Imposible conectar"
                                    }else{
                                         self.messError = "e-mail incorrecto"
                                         //print ("email incorrecto", error)
                                    }
                                    
                                }else{
                                    print ("Error en el sistema de login")
                                }
                                self.isError = true
                            }
                            
                        }
                        
                    }){
                        Text("Login")
                            .fontWeight(.bold)
                            .frame(width: UIScreen.main.bounds.width - 100)
                            .padding(.vertical)
                            .foregroundColor(.white)
                        
                        
                    }.background(Color("ColorLogo"))
                        .clipShape(Capsule())
                        .padding(.top,30)
                    
                    HStack{
                        
                        Text("¿Tienes una empresa?")
                            .font(.subheadline)
                            .padding(.leading)
                        
                        Button(action: {
                            self.showReg.toggle()
                        }){
                            Text("¡Regístrate ahora!")
                                .padding(.trailing)
                                .font(.subheadline)
                        }
                        
                    }
                    
                }.padding(.vertical,30)
                    .background(Color("Login"))
                    .cornerRadius(20)
                    .padding(20)
                Spacer()
            }//fin Vstack principal
        }
        .background(Color("Fondo").edgesIgnoringSafeArea(.all))
            //Mejoramos la navegacion
            .navigationBarHidden(true)
            .navigationBarTitle("")
           
            .offset(y: -self.offsetTeclado)
            .onAppear(){
               
                //recordamos al último usuario que inicio la sesión
                if UserDefaults.standard.object(forKey: "UserMail") != nil {
                    self.username = UserDefaults.standard.object(forKey: "UserMail") as! String
                }
                //calculamos la altura del teclado
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                    let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                    let altura = teclado.height
                    self.offsetTeclado = altura/1.5
                }
                
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                    self.offsetTeclado = 0
                }
        }
    }
}

struct LoginView_Previews: PreviewProvider {
    static var previews: some View {
        LoginView()
    }
}


