//
//  RecoveryPassView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 08/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseAuth

struct RecoveryPassView: View {
    
    @State private var texto:String = ""
    @State private var isError: Bool = false
    @State private var showAlert: Bool = false
    
    @Binding var showLogin:Bool
    
    var body: some View {
        
        VStack{
            HStack {
                Button(action:{
                    self.showLogin.toggle()
                }){
                    Image(systemName: "chevron.left") .padding(.leading,15).foregroundColor(.black)
                    Text("Volver").foregroundColor(.black)
                }
                
                Spacer()
            }
            HStack{
                Text("Recuperar contraseña").font(.title).bold().padding()
                Spacer()
            }
            
            VStack(alignment: .leading){
                
                Text("Intruduzca su dirección de correo electrónico:").padding()
                if isError{
                    HStack{
                        Spacer()
                        Text("e-mail incorrecto").foregroundColor(.red).padding(.bottom)
                        Spacer()
                    }
                    
                }
                FieldLoginView(texto: self.$texto, isEmail: true)
                HStack{
                    Spacer()
                    Button(action: {
                        Auth.auth().sendPasswordReset(withEmail: self.texto){ error in
                            if (error?.localizedDescription) != nil{
                                self.isError = true
                                //print("Ha habido un error",error)
                            }else{
                                self.showAlert.toggle()
                            }
                        }
                        
   
                    }){
                        Text("Enviar")
                            .fontWeight(.bold)
                            .frame(width: UIScreen.main.bounds.width - 200)
                            .padding(.vertical)
                            .foregroundColor(.white)
                        
                    } .alert(isPresented: self.$showAlert){
                        Alert(title: Text("Recuperar contraseña"), message: Text("Mensaje enviado correctamente. Consulte su buzón de correo electrónico"), dismissButton: .default(Text("Aceptar"), action:{
                            self.showAlert.toggle()
                            self.showLogin.toggle()
                            
                        }))
                    }
                    .background(Color("ColorLogo"))
                    .clipShape(Capsule())
                    .padding()
                    Spacer()
                }
                
                
                Text("* Recibirá un mensaje en su buzón de correo electronico con las instrucciones para reestablecer su contraseña.")
                    .font(.caption)
                    .padding()
                
            }
            .background(Color("Login"))
            .cornerRadius(20)
            .padding()
            
            Spacer()
        }.background(Color("Fondo").edgesIgnoringSafeArea(.all))
            .navigationBarHidden(true)
            .navigationBarTitle("")
        
    }
}

struct RecoveryPassView_Previews: PreviewProvider {
    static var previews: some View {
        RecoveryPassView(showLogin: .constant(false))
    }
}
