//
//  RegisterView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 19/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore
import FirebaseAuth

struct RegisterView: View {
    @State private var username: String = ""
    @State private var password: String = ""
    @State private var repassword: String = ""
    @State private var companyName: String = ""
    @State private var cif: String = ""
    @State private var strError: String = ""
    @State private var isError: Bool = false
    @State private var writeError: Bool = false
    @State private var showAlert: Bool = false
     @State private var offsetTeclado: CGFloat = 0
    
    @Binding var show: Bool
    
    private func crearAlerta()-> Alert{
        if self.writeError{
            return Alert(title: Text("Registro"), message: Text("El registro de la empresa \(self.companyName) y su usuario \(self.username) ha fallado"), dismissButton: .default(Text("Aceptar"), action:{
                self.showAlert.toggle()
                self.show.toggle()
                self.writeError.toggle()
                
            }))
        }else{
            return Alert(title: Text("Registro"), message: Text("El registro de la empresa \(self.companyName) y su usuario \(self.username) se ha completado correctamente "), dismissButton: .default(Text("Aceptar"), action:{
                self.showAlert.toggle()
                self.show.toggle()
                
            }))
        }
    }
    
    
    //Función para escribir en la base de datos
    private func registraEmpresa(){
        var ref: DocumentReference? = nil
        let db = Firestore.firestore()
        let campos : [String: Any] = ["nombre": self.companyName, "cif": self.cif]
        ref = db.collection("empresas").addDocument(data: campos){(error) in
            if error != nil{
                self.writeError = true
            }else{
                let campos : [String: Any] = ["mail": self.username, "isAdmin": true ]
                db.collection("empresas").document(ref!.documentID).collection("users").addDocument(data: campos){(error) in
                    if error != nil{
                        self.writeError = true
                    }else{
                        self.showAlert = true
                    }
                }
            }
            
        }
    }
    
    
    var body: some View {
           
        VStack{
            //Logo
            VStack{
                  ZStack{
                    VStack{
                        HStack(alignment: .top){
                            Button(action: {
                                self.show.toggle()
                            }){
                                HStack{
                                    Image(systemName: "chevron.left")
                                        .padding(.leading,20)
                                    Text("Volver")
                                    
                                }.foregroundColor(Color.black)
                                    
                            }
                            Spacer()
                        }
                        Spacer()
                    }
                    
                    Circle().foregroundColor(Color("ColorLogo"))
                        .frame(width: 150, height: 150)
                                .shadow(radius: 30)
                            Circle().foregroundColor(Color("Fondo"))
                                .frame(width: 120, height: 120)
                            
                            Image("gear").resizable().foregroundColor(.red)
                                .frame(width: 50, height: 50)
                                .offset(x: 20, y: -40)
                            
                            Image("logo1").resizable().foregroundColor(.red)
                                .frame(width: 150, height: 120)
                            
                            
                        }
                        Text("ControlWork")
                            .font(.largeTitle)
                            .bold()
                            .padding(.top,-10)
                    }

                //Formulario
                VStack (){
                    Text("Registro")
                        .font(.title)
                        .fontWeight(.bold)
                        .padding(.bottom)
                    if self.isError{
                        Text(self.strError).foregroundColor(.red)
                    }else{
                        Text("")
                    }
                    //Usuario
                    HStack{
                        
                        Text("Usuario")
                            .font(.title)
                        
                        Spacer()
                    }.padding(.leading)
                    
                    //Colocamos campos
                    FieldLoginView(texto: self.$username, isEmail: true)
                    FieldLoginView(texto: self.$password, isPass: true)
                    FieldLoginView(texto: self.$repassword, isRepass: true).padding(.bottom)
                    
                    //Empresa
                    HStack{
                        Text("Empresa")
                            .font(.title)
                        
                        Spacer()
                    }.padding(.leading)
                    
                    
                    //Colocamos campos
                    FieldLoginView(texto: self.$companyName, isCompany: true)
                    FieldLoginView(texto: self.$cif, isCompany: false).padding(.bottom)
                    
                    
                    
                    Button(action: {
                        if self.username.isEmpty{
                            self.strError = "Debe introducir un e-mail"
                            self.isError = true
                        }else if self.password.isEmpty{
                            self.strError = "Debe introducir una contraseña"
                            self.isError = true
                        }else if self.password != self.repassword{
                            self.strError = "Las contraseñas deben coicidir"
                            self.isError = true
                        }else{
                            self.isError = false
                            
                            Auth.auth().createUser(withEmail: self.username, password: self.password){ (user, error) in
                                if user != nil{
                                    self.registraEmpresa()
                                }else{
                                    //if (error?.localizedDescription) != nil{
                                    if let error = error?.localizedDescription{
                                        self.isError = true
                                        if error.contains("password"){
                                            self.strError = "pasword demasiado corto"
                                        }else if error.contains("another account"){
                                            self.strError = "e-mail ya registrado"
                                        }else{
                                             self.strError = "e-mail incorrecto"
                                        }
                                       
                                        print ("Error al escribir en la base de datos",error)
                                    }else{
                                        print ("Error en el sistema de registro")
                                    }
                                }
                                
                            }
                            
                            
                        }

                    }){
                        Text("Finalizar")
                            .fontWeight(.bold)
                            .frame(width: UIScreen.main.bounds.width - 100)
                            .padding(.vertical)
                            .foregroundColor(.white)
                        
                        
                    }.alert(isPresented: self.$showAlert){
                        self.crearAlerta()
                    }
                    
                    .background(Color("ColorLogo"))
                        .clipShape(Capsule())
                        .padding(.top)
                    
                    
                    
                }.padding()
                    .background(Color("Login"))
                    .cornerRadius(20)
                    .padding()
                    
                Spacer()
            }//fin Vstack principal
            .padding(.top)
              .background(Color("Fondo").edgesIgnoringSafeArea(.all))
               //Mejoramos la navegacion
               .navigationBarHidden(true)
               .navigationBarTitle("")
        .offset(y: -self.offsetTeclado)
            .onAppear(){
                //calculamos la altura del teclado
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                    let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                    let altura = teclado.height
                    self.offsetTeclado = altura/1.2
                }
                
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                    self.offsetTeclado = 0
                }
        }
           
                              
        
    }
}


struct RegisterView_Previews: PreviewProvider {
    static var previews: some View {
        RegisterView(show: .constant(true))
    }
}
