//
//  AgendaView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 20/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct AgendaView: View {
    
    private let usuario = UserDefaults.standard.object(forKey: "UserMail") as! String
    private let isAdmin = UserDefaults.standard.bool(forKey: "isAdmin")
    
    @State private var textAlert: String = ""
    @State private var showAlert: Bool = false
    @State private var showMenu: Bool = false
    @State private var showNew: Bool = false
    @State private var showEdit: Bool = false
    
    @State private var evento: Evento = Evento(id: "", inicio: Date(), fin: Date(), usuario: "", evento: "", observaciones: "")
    
    @ObservedObject var datos = GetEventos()
    @ObservedObject var rkManager = RKManager(calendar: Calendar.current, minimumDate: Date().addingTimeInterval(-60*60*24*365), maximumDate: Date().addingTimeInterval(60*60*24*365), mode: 0)
    
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.timeStyle = .none
        format.dateFormat = "dd/MM/yyyy"
        return format
    }
    private var timeFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .none
        format.dateFormat = "HH:mm"
        return format
    }
    
    private func getFormatDate(date:Date) -> String{
        let fecha = self.dateFormat.string(from: date)
        return fecha
    }
    
    var body: some View {
        
        ZStack{
            NavigationLink(destination: EditAgendaView(show: self.$showEdit, evento: self.evento), isActive: self.$showEdit){
                EmptyView()
            }
            
            NavigationView{
                VStack{
                    CalendarView(isPresented: .constant(true), rkManager: self.rkManager)
                    HStack{
                        Text("Eventos para el \(self.rkManager.selectedDate,formatter: self.dateFormat):")
                        Spacer()
                    }
                    List{
                        ForEach (self.datos.eventos){ evento in
                            if self.getFormatDate(date: self.rkManager.selectedDate).isEqual(self.getFormatDate(date: evento.inicio)){
                                Button(action:{
                                    self.evento = evento
                                    self.showEdit.toggle()
                                }){
                                    HStack(alignment: .top){
                                        VStack (alignment: .center){
                                            Text("\(evento.inicio, formatter: self.timeFormat)").font(.custom("Arial", size: 14))
                                            Text("\(evento.fin, formatter: self.timeFormat)").font(.custom("Arial", size: 14))
                                        }
                                        Divider()
                                        VStack(alignment: .leading){
                                            Text("\(evento.usuario)").font(.custom("Arial", size: 14)).bold()
                                            Text("\(evento.evento)")
                                        }
                                        
                                    }
                                }
                            }
                            
                        }
                    }
                }.navigationBarTitle("Agenda", displayMode: .inline)
                    .navigationBarItems(leading:
                        Button(action:{
                            self.showMenu.toggle()
                        }){
                            Image (systemName: "person.crop.circle")
                                .resizable()
                                .frame(width: 35, height: 35)
                        }, trailing:
                        Button(action:{
                            self.showNew.toggle()
                        }){
                            Image (systemName: "plus")
                                .resizable()
                                .frame(width: 25, height: 25)
                        }.sheet(isPresented: self.$showNew){
                            NewAgenda(show:self.$showNew)
                    })
            }.offset(x: self.showMenu ? UIScreen.main.bounds.width/1.5 : 0).transition(.move(edge: self.showMenu ? .leading : .trailing))
            
            if self.showMenu{
                GeometryReader{_ in
                    MenuView(show: self.$showMenu)
                        .offset(x: UIScreen.main.bounds.width / -4.5)
                        .padding(.bottom,-30)
                        .edgesIgnoringSafeArea(.top)
                        .transition(.move(edge: .leading))
                }.background(Color.white.opacity(0.01))
                    .onTapGesture {
                        self.showMenu.toggle()
                }
                
            }
        }//Mejoramos la navegacion
            .navigationBarTitle("")
            .navigationBarHidden(true)
        
        
    }
}

struct AgendaView_Previews: PreviewProvider {
    static var previews: some View {
        AgendaView()
    }
}
