//
//  AusenciasView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 20/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct AusenciasView: View {
    
    @State private var showPendientes: Bool = false
    @State private var showNew : Bool = false
    @State private var showEdit : Bool = false
    @State private var showUsers : Bool = false
    @State private var showMenu : Bool = false
    @State private var userID: String = ""
    @State private var selected: String = "Todos"
    @State private var currentUser: String = "Todos los usuarios"
    @State private var ausencia: Ausencia = Ausencia(id: "", tipo: "", inicio: Date(), fin: Date(), adjunto: "", estado: "", observaciones: "", user: "", userID: "")
    
    private let isAdmin = UserDefaults.standard.bool(forKey: "isAdmin")
    
    @ObservedObject var datos = GetAusencias()
    @ObservedObject var users = GetUsers()
    
    private var dateFormat: DateFormatter{
        let format = DateFormatter()
        format.dateFormat = "dd/MM/yy"
        return format
    }
    //Función que retorna el id de un usuario con un determinado mail
    private func getUserID(user:String)->String{
        var id = ""
        let mail = user
        for user in users.users{
            if user.mail.isEqual(mail){
                id = user.id
            }
        }
        return id
    }
    
    var body: some View {
        
        ZStack{
            NavigationLink(destination: EditAusenciaView(show: self.$showEdit, ausencia: self.$ausencia),isActive: self.$showEdit){
                EmptyView()
            }
            
            NavigationView{
                VStack{
                    //Cabecera
                    if self.isAdmin{
                        Button(action:{
                            self.showUsers.toggle()
                        }){
                            Text(self.currentUser).bold()
                            Image(systemName: "chevron.down")
                                .rotationEffect(.degrees(self.showUsers ? 180:0))
                        }
                    }else{
                        HStack{
                            Text("Solicitudes").font(.largeTitle)
                            Spacer()
                        }.padding(.horizontal)
                        
                    }
                    
                    //Scroll de usuarios
                    if self.showUsers{
                        HStack{
                            ScrollView(.horizontal, showsIndicators: false){
                                HStack(spacing: 10){
                                    Button(action:{
                                        self.selected = "Todos"
                                        self.currentUser = "Todos los usuarios"
                                    }){
                                        UserFrameView(name: "Todos", mail: "@")
                                    }
                                    
                                    ForEach (self.users.users) { user in
                                        Button(action:{
                                            self.selected = user.mail
                                            self.currentUser = user.nombre
                                            //self.userID = user.id
                                        }){
                                            UserFrameView(name: user.nombre, mail:user.mail)
                                        }.foregroundColor(.black)
                                        
                                    }
                                }.padding()
                                
                            }
                            
                        }.background(Color("Barras"))
                    }
                    
                    //Sólo pendientes
                    Toggle(isOn: self.$showPendientes){
                        
                        HStack{
                            Spacer()
                            Text("Sólo pendientes")
                        }
                        
                    }.padding(.horizontal).padding(.top)
                    Divider().padding(.horizontal).padding(.top)
                    
                    List{
                        if showPendientes{
                            if self.selected.isEqual("Todos"){
                                ForEach (self.datos.ausencias){ ausencia in
                                    if ausencia.estado.isEqual("Pendiente"){
                                        Button(action:{
                                            self.ausencia = ausencia
                                            self.ausencia.userID = self.getUserID(user: self.ausencia.userID)
                                            self.showEdit.toggle()
                                        }){
                                            VStack{
                                                HStack{
                                                    Text("\(ausencia.tipo)").font(.title)
                                                    if self.isAdmin{
                                                        Text("(\(ausencia.user))")
                                                    }
                                                    Spacer()
                                                }
                                                HStack{
                                                    Text("Del \(ausencia.inicio, formatter: self.dateFormat) al \(ausencia.fin, formatter: self.dateFormat)").font(.footnote)
                                                    Spacer()
                                                    Text(ausencia.estado).foregroundColor(.orange)
                                                    
                                                }.padding(.top,7)
                                                
                                            }
                                        }
                                    }
                                }
                            }else{
                                ForEach (self.datos.ausencias){ ausencia in
                                    if ausencia.estado.isEqual("Pendiente") && ausencia.userID.isEqual(self.selected){
                                        Button(action:{
                                            self.ausencia = ausencia
                                            self.ausencia.userID = self.getUserID(user: self.ausencia.userID)
                                            self.showEdit.toggle()
                                        }){
                                            VStack{
                                                HStack{
                                                    Text("\(ausencia.tipo)").font(.title)
                                                    if self.isAdmin{
                                                        Text("(\(ausencia.user))")
                                                    }
                                                    Spacer()
                                                }
                                                HStack{
                                                    Text("Del \(ausencia.inicio, formatter: self.dateFormat) al \(ausencia.fin, formatter: self.dateFormat)").font(.footnote)
                                                    Spacer()
                                                    Text(ausencia.estado).foregroundColor(.orange)
                                                    
                                                }.padding(.top,7)
                                                
                                            }
                                        }
                                    }
                                }
                            }
                        }else{
                            if self.selected.isEqual("Todos"){
                                ForEach (self.datos.ausencias){ ausencia in
                                    Button(action:{
                                        self.ausencia = ausencia
                                        self.ausencia.userID = self.getUserID(user: self.ausencia.userID)
                                        self.showEdit.toggle()
                                    }){
                                        VStack{
                                            HStack{
                                                Text("\(ausencia.tipo)").font(.title)
                                                if self.isAdmin{
                                                    Text("(\(ausencia.user))")
                                                }
                                                Spacer()
                                            }
                                            HStack{
                                                Text("Del \(ausencia.inicio, formatter: self.dateFormat) al \(ausencia.fin, formatter: self.dateFormat)").font(.footnote)
                                                Spacer()
                                                if ausencia.estado.isEqual("Aprobada"){
                                                    Text(ausencia.estado).foregroundColor(.green)
                                                }else{
                                                    if ausencia.estado.contains("Pendiente"){
                                                        Text(ausencia.estado).foregroundColor(.orange)
                                                    }else{
                                                        Text(ausencia.estado).foregroundColor(.red)
                                                    }
                                                    
                                                }
                                                
                                            }
                                            
                                        }
                                    }
                                }
                            }else{
                                ForEach (self.datos.ausencias){ ausencia in
                                    if ausencia.userID.isEqual(self.selected){
                                        Button(action:{
                                            self.ausencia = ausencia
                                            self.ausencia.userID = self.getUserID(user: self.ausencia.userID)
                                            self.showEdit.toggle()
                                        }){
                                            VStack{
                                                HStack{
                                                    Text("\(ausencia.tipo)").font(.title)
                                                    if self.isAdmin{
                                                        Text("(\(ausencia.user))")
                                                    }
                                                    Spacer()
                                                }
                                                HStack{
                                                    Text("Del \(ausencia.inicio, formatter: self.dateFormat) al \(ausencia.fin, formatter: self.dateFormat)").font(.footnote)
                                                    Spacer()
                                                    if ausencia.estado.isEqual("Aprobada"){
                                                        Text(ausencia.estado).foregroundColor(.green)
                                                    }else{
                                                        if ausencia.estado.contains("Pendiente"){
                                                            Text(ausencia.estado).foregroundColor(.orange)
                                                        }else{
                                                            Text(ausencia.estado).foregroundColor(.red)
                                                        }
                                                        
                                                    }
                                                    
                                                }
                                                
                                            }
                                        }
                                        
                                    }
                                }
                            }
                            
                        }
                        
                    }
                    
                    
                }
                .navigationBarTitle("Ausencias", displayMode: .inline).padding(.vertical)
                .navigationBarItems(leading:
                    Button(action:{
                        self.showMenu.toggle()
                    }){
                        Image (systemName: "person.crop.circle")
                            .resizable()
                            .frame(width: 35, height: 35)
                    },trailing:
                    
                    Button(action:{
                        self.showNew.toggle()
                    }){
                        Image (systemName: "plus")
                            .resizable()
                            .frame(width: 25, height: 25)
                    }.sheet(isPresented: self.$showNew){
                        NewAusenciaView(show: self.$showNew)
                })
                
                
            }.offset(x: self.showMenu ? UIScreen.main.bounds.width/1.5 : 0).transition(.move(edge: self.showMenu ? .leading : .trailing))
            
            if self.showMenu{
                GeometryReader{_ in
                    MenuView(show: self.$showMenu)
                        .offset(x: UIScreen.main.bounds.width / -4.5)
                        .padding(.bottom,-30)
                        .edgesIgnoringSafeArea(.top)
                        .transition(.move(edge: .leading))
                }.background(Color.white.opacity(0.01))
                    .onTapGesture {
                        self.showMenu.toggle()
                }
                
            }
        }
            //Mejoramos la navegacion
            .navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
}

struct AusenciasView_Previews: PreviewProvider {
    static var previews: some View {
        AusenciasView()
    }
}
