//
//  HorarioView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 20/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct BaseHorarioView: View {
    
   
    @Binding var selected: Int
    
    @State private var showMenu: Bool = false
    @State private var showUsers: Bool = false
    
    private let isAdmin:Bool = UserDefaults.standard.bool(forKey: "isAdmin")
    
    var body: some View {
        ZStack{
            NavigationLink(destination: RegistroUsersView(show:self.$showUsers), isActive: self.$showUsers){
                                   EmptyView()
                               }
        
            NavigationView{
                    VStack{
                        Picker(selection: self.$selected, label: Text("")){
                            Text("Hoy").tag(0)
                            Text("Registro").tag(1)
                            
                        }.pickerStyle(SegmentedPickerStyle())
                            
                            .padding(.horizontal,80)
                            .padding(.vertical,5)
                        Spacer()
                        if self.selected == 0{
                            VStack{
                                HorarioView()
                                Spacer()
                            }
                            
                        }else{
                            RegistroHorarioView()
                            Spacer()
                        }
                        Spacer()
                    }
                    
                .navigationBarTitle("Horario", displayMode: .inline)
                .navigationBarItems(leading:
                    Button(action:{
                        self.showMenu.toggle()
                    }){
                        Image (systemName: "person.crop.circle")
                            .resizable()
                            .frame(width: 35, height: 35)
                    },trailing:
                    Button(action:{
                        self.showUsers.toggle()
                    }){
                        if self.isAdmin && self.selected == 1{
                            Text("Usuarios")
                        }
                })
                
                
            }.offset(x: self.showMenu ? UIScreen.main.bounds.width/1.5 : 0).transition(.move(edge: self.showMenu ? .leading : .trailing))

            //Menu
            if self.showMenu{
                GeometryReader{_ in
                    MenuView(show: self.$showMenu)
                        .offset(x: UIScreen.main.bounds.width / -4.5)
                        .edgesIgnoringSafeArea(.top)
                        .padding(.bottom,-30)
                        .transition(.move(edge: .leading))
                }.background(Color.white.opacity(0.01))
                    .onTapGesture {
                        self.showMenu.toggle()
                }
            }
        }
            //Mejoramos la navegacion
            .navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
}

struct BaseHorarioView_Previews: PreviewProvider {
    static var previews: some View {
        BaseHorarioView(selected: .constant(0))
    }
}
