//
//  EditAgendaView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 08/05/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct EditAgendaView: View {
    
    @Binding var show: Bool
    
    @State var evento: Evento
    
    @State private var textAlert: String = ""
    @State private var showAlert: Bool = false
    @State private var permiso: Bool = false
    @State private var isEdit: Bool = false
    
    @State private var showDate: Bool = false
    @State private var showInicio: Bool = false
    @State private var showFin: Bool = false
    
    @State private var offsetTeclado: CGFloat = 0
    @State private var needTeclado:Bool = false
    
    private let usuario = UserDefaults.standard.object(forKey: "UserMail") as? String ?? ""
    private let isAdmin = UserDefaults.standard.bool(forKey: "isAdmin")
    @State var empresaID = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.timeStyle = .none
        format.dateFormat = "EEEE, dd/MM/yyyy"
        return format
    }
    private var timeFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .none
        format.dateFormat = "HH:mm"
        return format
    }
    
    //Función para actualizar un evento en la base de datos
    private func actualizaEvento(){
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["evento": self.evento.evento, "inicio": self.evento.inicio, "fin":self.evento.fin,"observaciones": self.evento.observaciones]
        let doc = db.collection("empresas").document(self.empresaID).collection("eventos").document(self.evento.id)
        
        doc.updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al actualizar el registro en la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡El evento se ha actualizado corréctamente!"
                self.showAlert.toggle()
            }
        }
    }
   //Función de pruebas para actualizar un evento en la base de datos: es la misma función, sin generar alertas, recibiendo un clousure como parámetro)
    func actualizaEvento(clousure: @escaping (Error?)->()){
        var err:Error? = nil
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["evento": self.evento.evento, "inicio": self.evento.inicio, "fin":self.evento.fin,"observaciones": self.evento.observaciones]
        let doc = db.collection("empresas").document(self.empresaID).collection("eventos").document(self.evento.id)
        
        doc.updateData(campos){(error) in
            if error != nil{
                err = error
            }
        }
        clousure(err)
    }
    //Función para actualizar un evento en la base de datos
    private func eliminaEvento(){
        let db = Firestore.firestore()
        let doc = db.collection("empresas").document(self.empresaID).collection("eventos").document(self.evento.id)
        
        doc.delete(){(error) in
            if error != nil{
                self.textAlert = "¡Error al eliminar el registro en la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡El evento fué eliminado corréctamente!"
                self.showAlert.toggle()
            }
        }
    }
    
    //Función de pruebas para eliminar un evento de la base de datos: es la misma función, sin generar alertas, recibiendo un clousure como parámetro)
    func eliminaEvento(clousure: @escaping (Error?)->()){
        var err:Error? = nil
        
        let db = Firestore.firestore()
        let doc = db.collection("empresas").document(self.empresaID).collection("eventos").document(self.evento.id)
        
        doc.delete(){(error) in
            if error != nil{
                err = error
            }
        }
        clousure(err)
    }
    
    var body: some View {
        NavigationView{
            VStack{
                //Cuerpo
                if self.isEdit{
                    VStack{
                        //Evento
                        VStack{
                            VStack{
                                HStack{
                                    Text("Evento: ").foregroundColor(.green)
                                    Spacer()
                                }
                                HStack{
                                    TextField("Evento", text: self.$evento.evento)
                                        .onTapGesture {
                                            self.needTeclado = false
                                    }
                                    Spacer()
                                    
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                
                            }
                            
                        }
                        .padding()
                        .background(Color("Fondo").opacity(0.6))
                        .cornerRadius(10)
                        .padding(.top)
                        
                        //fechas
                        VStack{
                            VStack{
                                //dia
                                VStack{
                                    HStack{
                                        Text("Día: ").foregroundColor(.green)
                                        Spacer()
                                        HStack{
                                            Spacer()
                                            Button(action:{
                                                self.showInicio = false
                                                self.showFin = false
                                                self.evento.fin = self.evento.inicio
                                                self.showDate.toggle()
                                            }){
                                                Text("\(self.evento.inicio, formatter: self.dateFormat)").foregroundColor(.black)
                                                Image(systemName: "chevron.down").foregroundColor(.black)
                                            }
                                            Spacer()
                                        }.padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    if self.showDate{
                                        HStack{
                                            Spacer()
                                            DatePicker(selection: self.$evento.inicio,displayedComponents: .date){
                                                Text("")
                                            }.onTapGesture {
                                                self.showDate.toggle()
                                                self.evento.fin = self.evento.inicio
                                            }
                                            
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                        
                                    }
                                }
                                //Horas
                                VStack{
                                    //inicio
                                    HStack{
                                        Text("Hora de inicio:").foregroundColor(.green)
                                        Spacer()
                                        HStack{
                                            Button(action:{
                                                self.showDate = false
                                                self.showFin = false
                                                self.evento.fin = self.evento.inicio
                                                self.showInicio.toggle()
                                                
                                            }){
                                                Text("\(self.evento.inicio, formatter: self.timeFormat) horas. ").foregroundColor(.black)
                                                Image(systemName: "chevron.down").foregroundColor(.black)
                                                
                                            }
                                        }.padding(.horizontal,15).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                        
                                    }
                                    if self.showInicio{
                                        HStack{
                                            Spacer()
                                            DatePicker(selection: self.$evento.inicio,displayedComponents: .hourAndMinute){
                                                Text("")
                                            }.onTapGesture {
                                                self.showInicio.toggle()
                                                self.evento.fin = self.evento.inicio
                                            }
                                            
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                        
                                    }
                                    //fin
                                    HStack{
                                        Text("Hora final:").foregroundColor(.green)
                                        Spacer()
                                        HStack{
                                            Button(action:{
                                                self.showDate = false
                                                self.showInicio = false
                                                self.showFin.toggle()
                                            }){
                                                Text("\(self.evento.fin, formatter: self.timeFormat) horas. ").foregroundColor(.black)
                                                Image(systemName: "chevron.down").foregroundColor(.black)
                                                
                                            }
                                        }.padding(.horizontal,15).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                        
                                    }
                                    if self.showFin{
                                        HStack{
                                            Spacer()
                                            DatePicker(selection: self.$evento.fin,in: self.evento.inicio...,displayedComponents: .hourAndMinute){
                                                Text("")
                                            }.onTapGesture {
                                                self.showFin.toggle()
                                            }
                                            
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                        
                                    }
                                }
                            }.padding()
                        }.background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        
                        //Observaciones
                        VStack{
                            HStack{
                                Text("Observaciones:").foregroundColor(.green)
                                Spacer()
                            }
                            VStack{
                                HStack{
                                    MultiTextField(text: self.$evento.observaciones, texto: self.evento.observaciones)
                                        .onTapGesture {
                                            self.needTeclado = true
                                        }
                                    Spacer()
                                }.padding(-10)
                                
                                Spacer()
                            }.padding()
                                .background(Color.white)
                                .cornerRadius(10)
                            
                        }.padding() .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        
                        //Eliminar
                       
                        VStack{
                           
                                Button(action:{
                                    self.permiso.toggle()
                                }){
                                    HStack{
                                    Spacer()
                                    Text("Eliminar").foregroundColor(.red).bold()
                                    Spacer()
                                    }
                                }.padding().background(Capsule().stroke(Color.red, lineWidth: 2)
                                .background(Color("Fondo").opacity(0.6)))
                                .clipShape(Capsule())
                                .alert(isPresented: self.$permiso){
                                    Alert(title: Text("Eventos"), message: Text("¿Desea eliminar el evento?"), primaryButton: .cancel(), secondaryButton: .default(Text("Aceptar"),action: {
                                        self.eliminaEvento()
                                    }))
                                }
                                
                        }.padding(.vertical)
                        
                    }.padding(.horizontal).background(Color.white).offset(y:-self.offsetTeclado)
                }else{
                    VStack{
                        //Evento
                        VStack{
                            VStack{
                                HStack{
                                    Text("Evento: ")
                                    Spacer()
                                }
                                HStack{
                                    TextField("Evento", text: self.$evento.evento).disabled(true)
                                    Spacer()
                                    
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                
                            }
                            
                        }
                        .padding()
                        .background(Color("Fondo").opacity(0.6))
                        .cornerRadius(10)
                        .padding(.top)
                        
                        //fechas
                        VStack{
                            VStack{
                                //dia
                                VStack{
                                    HStack{
                                        Text("Día: ")
                                        Spacer()
                                        HStack{
                                            Spacer()
                                            Button(action:{
                                                self.showInicio = false
                                                self.showFin = false
                                                self.evento.fin = self.evento.inicio
                                                self.showDate.toggle()
                                            }){
                                                Text("\(self.evento.inicio, formatter: self.dateFormat)").foregroundColor(.black)
                                                Image(systemName: "chevron.down").foregroundColor(.black)
                                            }.disabled(true)
                                            Spacer()
                                        }.padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    if self.showDate{
                                        HStack{
                                            Spacer()
                                            DatePicker(selection: self.$evento.inicio,displayedComponents: .date){
                                                Text("")
                                            }.onTapGesture {
                                                self.showDate.toggle()
                                                self.evento.fin = self.evento.inicio
                                            }
                                            
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                        
                                    }
                                }
                                //Horas
                                VStack{
                                    //inicio
                                    HStack{
                                        Text("Hora de inicio:")
                                        Spacer()
                                        HStack{
                                            Button(action:{
                                                self.showDate = false
                                                self.showFin = false
                                                self.evento.fin = self.evento.inicio
                                                self.showInicio.toggle()
                                                
                                            }){
                                                Text("\(self.evento.inicio, formatter: self.timeFormat) horas. ").foregroundColor(.black)
                                                Image(systemName: "chevron.down").foregroundColor(.black)
                                                
                                            }.disabled(true)
                                        }.padding(.horizontal,15).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                        
                                    }
                                    if self.showInicio{
                                        HStack{
                                            Spacer()
                                            DatePicker(selection: self.$evento.inicio,displayedComponents: .hourAndMinute){
                                                Text("")
                                            }.onTapGesture {
                                                self.showInicio.toggle()
                                                self.evento.fin = self.evento.inicio
                                            }
                                            
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                        
                                    }
                                    //fin
                                    HStack{
                                        Text("Hora final:")
                                        Spacer()
                                        HStack{
                                            Button(action:{
                                                self.showDate = false
                                                self.showInicio = false
                                                self.showFin.toggle()
                                            }){
                                                Text("\(self.evento.fin, formatter: self.timeFormat) horas. ").foregroundColor(.black)
                                                Image(systemName: "chevron.down").foregroundColor(.black)
                                                
                                            }.disabled(true)
                                        }.padding(.horizontal,15).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                        
                                    }
                                    if self.showFin{
                                        HStack{
                                            Spacer()
                                            DatePicker(selection: self.$evento.fin,in: self.evento.inicio...,displayedComponents: .hourAndMinute){
                                                Text("")
                                            }.onTapGesture {
                                                self.showFin.toggle()
                                            }
                                            
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                        
                                    }
                                }
                            }.padding()
                        }.background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        
                        //Observaciones
                        VStack{
                            HStack{
                                Text("Observaciones:")
                                Spacer()
                            }
                            VStack{
                                HStack{
                                    MultiTextField(text: self.$evento.observaciones, texto: self.evento.observaciones).disabled(true)
                                    Spacer()
                                }.padding(-10)
                                
                                Spacer()
                            }.padding()
                                .background(Color.white)
                                .cornerRadius(10)
                            
                        }.padding() .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        
                    }.padding(.horizontal).background(Color.white)
                }
                
            }.onAppear(){
                //calculamos la altura del teclado
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                    let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                    let altura = teclado.height
                    if self.needTeclado{
                    self.offsetTeclado = altura/1.6
                    }
                }
                
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                    self.offsetTeclado = 0
                }
            }
            .navigationBarTitle("Agenda",displayMode: .inline)
            .navigationBarItems(leading:
                Button(action:{
                    self.show.toggle()
                }){
                    HStack{
                        Image(systemName: "chevron.left")
                        Text("Agenda")
                    }
                }
                ,trailing:
                Button(action:{
                    if self.isEdit{
                        self.actualizaEvento()
                    }else{
                        self.isEdit.toggle()
                    }
                }){
                    if self.evento.usuario.contains(self.usuario) || self.isAdmin{
                        if isEdit{
                            Text("Guardar")
                        }else{
                            Text("Editar")
                            
                        }
                    }

                }.alert(isPresented: self.$showAlert){
                    Alert(title: Text("Agenda"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                        if self.textAlert.contains("corréctamente"){
                            self.isEdit.toggle()
                            self.show.toggle()
                        }else{
                            self.textAlert = ""
                        }
                    }))
            })
        }.navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
}

struct EditAgendaView_Previews: PreviewProvider {
    static var previews: some View {
        EditAgendaView(show: .constant(false), evento: Evento(id: "", inicio: Date(), fin: Date(), usuario: "", evento: "", observaciones: ""))
    }
}
