//
//  EditAusenciaView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 21/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct EditAusenciaView: View {
    
    @Binding var show: Bool
    @Binding var ausencia: Ausencia
    
    @State private var isEdit: Bool = false
    
    @State private var showTipo: Bool = false
    @State private var isInicio: Bool = false
    @State private var isFinal: Bool = false
    @State private var showAlert: Bool = false
    @State private var tipo:String = "Vacaciones"
    @State private var inicio: Date = Date()
    @State private var final: Date = Date()
    @State private var observaciones: String = ""
    @State private var estado: String = ""
    @State private var offsetTeclado: CGFloat = 0
    
    @State private var textAlert: String = ""
    
    private let tipos = ["Baja médica","Visita Médica","Vacaciones","Días personales","Salida oficial"]
    private let isAdmin = UserDefaults.standard.bool(forKey: "isAdmin")
    private let empresaID = UserDefaults.standard.object(forKey: "EmpresaID") as! String

    
    private var dateFormatVisita:DateFormatter{
        let format = DateFormatter()
        format.dateFormat = "EEEE, dd/MM/yyyy HH:mm"
        return format
    }
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.dateFormat = "EEEE, dd/MM/yyyy"
        return format
    }

    //Función para actualizar una ausencia en la base de datos
    private func actualizaAusencia(){
        let db = Firestore.firestore()
        let campos : [String: Any] = ["tipo":self.ausencia.tipo, "inicio": self.ausencia.inicio, "final": self.ausencia.fin, "adjunto":self.ausencia.adjunto,"estado": self.ausencia.estado, "mensaje":self.ausencia.observaciones]
        let doc = db.collection("empresas").document(self.empresaID).collection("users").document(self.ausencia.userID).collection("ausencias").document(self.ausencia.id)
            
            doc.updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al actualizar el registro en la base de datos!"
                print(error!.localizedDescription)
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡La ausencia se ha actualizado corréctamente!"
                self.showAlert.toggle()
            }
            
        }
    }
    
    //Función para eliminar una ausencia en la base de datos
    private func eliminaAusencia(){
        let db = Firestore.firestore()
        let doc = db.collection("empresas").document(self.empresaID).collection("users").document(self.ausencia.userID).collection("ausencias").document(self.ausencia.id)
            
        doc.delete(){(error) in
            if error != nil{
                self.textAlert = "¡Error al eliminar el registro en la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡La ausencia fué eliminada corréctamente!"
                self.showAlert.toggle()
            }
            
        }
    }
    
    
    var body: some View {
        NavigationView{
            ZStack{
                VStack{
                    //Cuerpo
                    VStack{
                        if self.isEdit{
                            //Tipo
                            VStack{
                                HStack{
                                    Text("Ausencia:")
                                    Spacer()
                                    Button(action:{
                                        self.showTipo.toggle()
                                    }){
                                        HStack{
                                            Spacer()
                                            Text(self.ausencia.tipo)
                                            Image(systemName: "chevron.down").rotationEffect(.degrees(self.showTipo ? 180:0))
                                            Spacer()
                                        }
                                    }
                                    .padding(.horizontal,30).padding(.vertical,7)
                                    .background(Color.white).cornerRadius(10)
                                }
                            }
                            .padding()
                            .background(Color("Fondo").opacity(0.6))
                            .cornerRadius(10)
                            
                            //fechas
                            VStack{
                                VStack{
                                    //Inicio
                                    VStack{
                                        HStack{
                                            Text("Empieza:")
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            Spacer()
                                            Button(action:{
                                                self.isInicio.toggle()
                                                self.isFinal = false
                                            }){
                                                if self.ausencia.tipo.contains("Visita"){
                                                    Text("\(self.ausencia.inicio, formatter:self.dateFormatVisita)")
                                                    Image(systemName: "chevron.down").rotationEffect(.degrees(self.isInicio ? 180:0))
                                                }else{
                                                    Text("\(self.ausencia.inicio, formatter:self.dateFormat)")
                                                    Image(systemName: "chevron.down").rotationEffect(.degrees(self.isInicio ? 180:0))
                                                }
                                                
                                            }
                                            Spacer()
                                            
                                        }.padding(.horizontal).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                        if self.isInicio{
                                            if self.ausencia.tipo.contains("Visita"){
                                                HStack{
                                                    DatePicker(selection: self.$ausencia.inicio){
                                                        Text("")
                                                    }.onTapGesture {
                                                        self.isInicio.toggle()
                                                    }
                                                }.padding(.horizontal,-15).padding(.vertical,7)
                                            }else{
                                                HStack{
                                                    DatePicker(selection: self.$ausencia.inicio,displayedComponents: .date){
                                                        Text("")
                                                    }.onTapGesture {
                                                        self.isInicio.toggle()
                                                    }
                                                }.padding(.horizontal,-15).padding(.vertical,7)
                                            }
                                            
                                        }
                                    }
                                    
                                    //Final
                                    VStack{
                                        HStack{
                                            Text("Acaba:")
                                            Spacer()
                                        }
                                        HStack{
                                            Spacer()
                                            Button(action:{
                                                self.isFinal.toggle()
                                                self.isInicio = false
                                            }){
                                                if self.ausencia.tipo.contains("Visita"){
                                                    Text("\(self.ausencia.fin, formatter:self.dateFormatVisita)")
                                                    Image(systemName: "chevron.down").rotationEffect(.degrees(self.isFinal ? 180:0))
                                                }else{
                                                    Text("\(self.ausencia.fin, formatter:self.dateFormat)")
                                                    Image(systemName: "chevron.down").rotationEffect(.degrees(self.isFinal ? 180:0))
                                                }
                                                
                                            }
                                            Spacer()
                                            
                                        }.padding(.horizontal).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                        if self.isFinal{
                                            if self.ausencia.tipo.contains("Visita"){
                                                HStack{
                                                    DatePicker(selection: self.$ausencia.fin){
                                                        Text("")
                                                    }.onTapGesture {
                                                        self.isFinal.toggle()
                                                    }
                                                }.padding(.horizontal,-15).padding(.vertical,7)
                                            }else{
                                                HStack{
                                                    DatePicker(selection: self.$ausencia.fin,in: self.inicio...,displayedComponents: .date){
                                                        Text("")
                                                    }.onTapGesture {
                                                        self.isFinal.toggle()
                                                    }
                                                }.padding(.horizontal,-15).padding(.vertical,7)
                                            }
                                            
                                        }
                                    }
                                    
                                }.padding()
                            }.background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            
                            //Adjuntos
                            HStack{
                                VStack(alignment: .leading){
                                    Text("Adjuntos: ")
                                    HStack{
                                        HStack{
                                            Spacer()
                                            Text("docVisita.pdf").padding(.vertical,7).padding(.horizontal)
                                            
                                        }.background(Color.white)
                                            .cornerRadius(10)
                                        Button(action:{
                                            self.textAlert = "Función no disponible en la versión actual."
                                            self.showAlert.toggle()
                                        }){
                                            Image(systemName: "paperclip")
                                            .resizable()
                                            .frame(width: 25, height: 25)
                                        }
                                    }
                                }
                                
                            }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            
                            // Observaciones
                            VStack{
                                HStack{
                                    Text("Observaciones:")
                                    Spacer()
                                    
                                }
                                VStack{
                                    ZStack{
                                        HStack{
                                            MultiTextField(text: self.$ausencia.observaciones, texto: self.ausencia.observaciones)
                                            Spacer()
                                        }.padding(-10)
                                        VStack{         //Damos altura al cuadro ya que el ScrollView anula los Spacer
                                            Text("")
                                                .padding(.bottom,100)
                                        }
                                        
                                    }
                                    
                                }.padding()
                                    .background(Color.white)
                                    .cornerRadius(10)
                                
                            }.padding() .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            
                            
                            //Eliminar
                            VStack{
                                Button(action:{
                                    self.eliminaAusencia()
                                }){
                                    HStack{
                                        Spacer()
                                        Text("Eliminar").foregroundColor(.red).bold()
                                        Spacer()
                                    }
                                }.padding().background(Capsule().stroke(Color.red, lineWidth: 2)
                                    .background(Color("Fondo").opacity(0.6)))
                                    .clipShape(Capsule())
                                
                            }
                        }else{
                            //Tipo
                            VStack{
                                HStack{
                                    Text("Ausencia:")
                                    Spacer()
                                    
                                    HStack{
                                        Spacer()
                                        Text(self.ausencia.tipo)
                                        Spacer()
                                    }
                                        
                                    .padding(.horizontal,40).padding(.vertical,7)
                                    .background(Color.white).cornerRadius(10)
                                }
                            }
                            .padding()
                            .background(Color("Fondo").opacity(0.6))
                            .cornerRadius(10)
                            
                            //fechas
                            VStack{
                                VStack{
                                    //Inicio
                                    VStack{
                                        HStack{
                                            Text("Empieza:")
                                            Spacer()
                                        }.padding(.bottom,10)
                                        
                                        HStack{
                                            Spacer()
                                            if self.ausencia.tipo.contains("Visita"){
                                                Text("\(self.ausencia.inicio, formatter:self.dateFormatVisita)")
                                            }else{
                                                Text("\(self.ausencia.inicio, formatter:self.dateFormat)")
                                            }
                                            Spacer()
                                            
                                        }.padding(.horizontal).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                    //Final
                                    VStack{
                                        HStack{
                                            Text("Acaba:")
                                            Spacer()
                                        }.padding(.top,7)
                                        HStack{
                                            Spacer()
                                            if self.ausencia.tipo.contains("Visita"){
                                                Text("\(self.ausencia.fin, formatter:self.dateFormatVisita)")
                                                Image(systemName: "chevron.down")
                                            }else{
                                                Text("\(self.ausencia.fin, formatter:self.dateFormat)")
                                                Image(systemName: "chevron.down")
                                            }
                                            Spacer()
                                            
                                        }.padding(.horizontal).padding(.vertical,10)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                }.padding()
                            }.background(Color("Fondo").opacity(0.6)).cornerRadius(10).padding(.top,10)
                            
                            //Adjuntos
                            HStack{
                                VStack(alignment: .leading){
                                    HStack{
                                        Text("Adjuntos: ")
                                        Spacer()
                                        Image(systemName: "paperclip")
                                            .resizable()
                                            .frame(width: 25, height: 25)
                                    }
                                    
                                    HStack{
                                        HStack{
                                            Spacer()
                                            Text("docVisita.pdf").padding(.vertical,7).padding(.horizontal)
                                            
                                        }.background(Color.white)
                                            .cornerRadius(10)
                                        
                                    }
                                }
                                
                            }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10).padding(.bottom,10)
                            
                            // Observaciones
                            VStack{
                                HStack{
                                    Text("Observaciones:")
                                    Spacer()
                                    
                                }
                                VStack{
                                    ZStack{
                                        HStack{
                                            MultiTextField(text: self.$ausencia.observaciones, texto: self.ausencia.observaciones).disabled(true)
                                            Spacer()
                                        }.padding(-10)
                                        VStack{         //Damos altura al cuadro ya que el ScrollView anula los Spacer
                                            Text("")
                                                .padding(.bottom,100)
                                        }
                                        
                                    }
                                    
                                }.padding()
                                    .background(Color.white)
                                    .cornerRadius(10)
                                
                            }.padding() .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            
                            //Autorización
                            HStack{
                                if self.ausencia.estado.isEqual("Pendiente"){
                                    if self.isAdmin{
                                        Button(action:{
                                            self.ausencia.estado = "Rechazada"
                                            self.actualizaAusencia()
                                        }){
                                            HStack{
                                                Spacer()
                                                Text("Rechazar").bold().foregroundColor(.red)
                                                Spacer()
                                            }
                                            
                                            
                                        }.padding()
                                            .background(Capsule().stroke(Color.red, lineWidth: 4))
                                            .background(Color("Fondo").opacity(0.3))
                                            .clipShape(Capsule())
                                        Spacer()
                                        Button(action:{
                                            self.ausencia.estado = "Aprobada"
                                            self.actualizaAusencia()
                                        }){
                                            Spacer()
                                            Text("Aprobar").bold().foregroundColor(.green)
                                            Spacer()
                                            
                                        }.padding()
                                            .background(Capsule().stroke(Color.green, lineWidth: 4))
                                            .background(Color("Fondo").opacity(0.3))
                                            .clipShape(Capsule())
                                        
                                    }else{
                                        HStack{
                                            Spacer()
                                            Text("Solicitud pendiente").bold().foregroundColor(.orange)
                                            Spacer()
                                            
                                        }.padding()
                                            .background(Capsule().stroke(Color.orange, lineWidth: 4))
                                            .background(Color("Fondo").opacity(0.3))
                                            .clipShape(Capsule())
                                    }
                                    
                                }else if self.ausencia.estado.isEqual("Aprobada"){
                                    HStack{
                                        Spacer()
                                        Text("Solicitud aprobada").bold().foregroundColor(.green)
                                        Spacer()
                                        
                                    }.padding()
                                        .background(Capsule().stroke(Color.green, lineWidth: 4))
                                        .background(Color("Fondo").opacity(0.3))
                                        .clipShape(Capsule())
                                }else{
                                    HStack{
                                        Spacer()
                                        Text("Solicitud rechazada").bold().foregroundColor(.red)
                                        Spacer()
                                        
                                    }.padding()
                                        .background(Capsule().stroke(Color.red, lineWidth: 4))
                                        .background(Color("Fondo").opacity(0.3))
                                        .clipShape(Capsule())
                                }
                                
                            }
                        }
                        
                    }.padding(.horizontal).background(Color.white).padding(.vertical)
                }.offset(y:-self.offsetTeclado)
                .padding(.bottom)
                    .navigationBarTitle("\(self.ausencia.user)",displayMode: .inline)
                    .navigationBarItems(leading:
                        Button(action:{
                            self.show.toggle()
                        }){
                            HStack{
                                Image(systemName: "chevron.left")
                                Text("Ausencias")
                            }
                        }
                        ,trailing:
                        Button(action:{
                            
                            if self.ausencia.estado.isEqual("Pendiente"){
                                if self.isEdit{
                                    self.actualizaAusencia()
                                }else{
                                    self.isEdit.toggle()
                                }
                            }else{
                                self.eliminaAusencia()
                            }
                            
                        }){
                            if self.ausencia.estado.isEqual("Pendiente"){
                                if self.isEdit{
                                    Text("Guardar")
                                }else{
                                    Text("Editar")
                                    
                                }
                            }else{
                                if self.isAdmin{
                                    Text("Eliminar")
                                }
                            }

                    }).alert(isPresented: self.$showAlert){
                        Alert(title: Text("Editar ausencias"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                            if self.textAlert.contains("corréctamente"){
                                self.show.toggle()
                            }else{
                                self.textAlert = ""
                            }
                        }))
                    }
                
                if self.showTipo{
                    GeometryReader{_ in
                        PickerDataView(estado: self.$ausencia.tipo, show: self.$showTipo, datos:self.tipos)
                        
                    }.background(Color.black.opacity(0.65))
                        .edgesIgnoringSafeArea(.vertical)
                        .onTapGesture {
                            withAnimation{
                                self.showTipo.toggle()
                            }
                    }
                }
            } .onAppear(){
                           //calculamos la altura del teclado
                           NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                               let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                               let altura = teclado.height
                               self.offsetTeclado = altura/1.2
                           }
                           
                           NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                               self.offsetTeclado = 0
                           }
                   }
            
        } .navigationBarTitle("")
            .navigationBarHidden(true)
        
        
    }
    
}

struct EditAusenciaView_Previews: PreviewProvider {
    static var previews: some View {
        EditAusenciaView(show: .constant(false), ausencia: .constant(Ausencia(id: "", tipo: "", inicio: Date(), fin: Date(), adjunto: "", estado: "", observaciones: "", user: "", userID: "")))
    }
}
