//
//  EditProyectoView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 19/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct EditProyectoView: View {
    //@Binding var isButton : Bool
    @Binding var show: Bool
    
    @State private var showAlert: Bool = false
    @State private var isEdit: Bool = false
    @State private var isInicio: Bool = false
    @State private var isFinal: Bool = false
    @State private var isEstado: Bool = false
  
    @State private var textAlert:String = ""
    @State private var offsetTeclado: CGFloat = 0
    @State private var needTeclado:Bool = false
    
    @State var proyecto:Proyecto
    
    private let estados = ["Inicial","Diseño","Desarrollo","Finalizado", "Cancelado"]
    private let isAdmin:Bool = UserDefaults.standard.bool(forKey: "isAdmin")
    
    //Formateador de fechas
    var dateFormat: DateFormatter{
        let format = DateFormatter()
        
        format.dateStyle = .full
        format.timeStyle = .none
        return format
    }
    
    //Función para actualizar un proyecto en la base de datos
    private func actualizaProyecto(){
        let db = Firestore.firestore()
        let campos : [String: Any] = ["nombre":self.proyecto.nombre, "cliente": self.proyecto.cliente, "responsable": self.proyecto.responsable, "inicio":self.proyecto.inicio,"entrega": self.proyecto.entrega, "estado":self.proyecto.estado, "mensaje":self.proyecto.mensaje]
        db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("proyectos").document(self.proyecto.id).updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al actualizar el proyecto a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡El proyecto se ha actualizado corréctamente!"
                self.showAlert.toggle()
            }
            
        }
    }
    
    
    var body: some View {
        NavigationView{
 
        ZStack(alignment: .bottom){
            VStack{
                ScrollView(.vertical,showsIndicators: false){
                    //Cuerpo
                    VStack{
                        if self.isEdit{
                            if self.isAdmin{
                                //Datos
                                VStack{
                                    VStack{
                                        HStack{
                                            Text("Nombre del proyecto:").foregroundColor(.green)
                                                .onTapGesture {
                                                    self.needTeclado = false
                                            }
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            TextField("Nombre", text: self.$proyecto.nombre)
                                            Spacer()
                                        }.padding(.horizontal).padding(.vertical,7)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                    //Cliente
                                    VStack{
                                        HStack{
                                            Text("Cliente:").foregroundColor(.green)
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            TextField("Cliente", text: self.$proyecto.cliente)
                                            .onTapGesture {
                                                    self.needTeclado = false
                                            }
                                            Spacer()
                                        }.padding(.horizontal).padding(.vertical,7)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                    //Responsable
                                    VStack{
                                        HStack{
                                            Text("Responsable:").foregroundColor(.green)
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            TextField("Responsable", text: self.$proyecto.responsable)
                                            .onTapGesture {
                                                    self.needTeclado = false
                                            }
                                            Spacer()
                                        }.padding(.horizontal).padding(.vertical,7)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                                //Fechas
                                VStack{
                                    
                                    VStack{
                                        
                                        VStack{
                                            //Inicio
                                            VStack{
                                                HStack{
                                                    Text("Inicio:").foregroundColor(.green)
                                                    Spacer()
                                                }
                                                
                                                Spacer()
                                                HStack{
                                                    Spacer()
                                                    Button(action:{
                                                        self.isFinal = false
                                                        self.isEstado = false
                                                        self.isInicio.toggle()
                                                        
                                                    }){
                                                        Text("\(self.proyecto.inicio, formatter: self.dateFormat)")
                                                        Image(systemName: "chevron.down")
                                                    }.foregroundColor(.black)
                                                    Spacer()
                                                }.padding(.horizontal,10).padding(.vertical,7)
                                                    .background(Color.white).cornerRadius(10)
                                                
                                            }
                                            if isInicio{
                                                HStack{
                                                    Spacer()
                                                    DatePicker(selection: self.$proyecto.inicio,displayedComponents: .date){
                                                        Text("")
                                                        
                                                    }.onTapGesture {
                                                        self.isInicio.toggle()
                                                    }
                                                }.padding(.horizontal,-15).padding(.vertical,7)
                                                
                                            }
                                            
                                            //Entrega
                                            VStack{
                                              HStack{
                                                    Text("Entrega:").foregroundColor(.green)
                                                    Spacer()
                                                }
                                                Spacer()
                                                HStack{
                                                    Spacer()
                                                    Button(action:{
                                                       
                                                        self.isInicio = false
                                                        self.isEstado = false
                                                        self.isFinal.toggle()
                                                        
                                                    }){
                                                        Text("\(self.proyecto.entrega, formatter: self.dateFormat)")
                                                        Image(systemName: "chevron.down")
                                                    }.foregroundColor(.black)
                                                    Spacer()
                                                }.padding(.horizontal,10).padding(.vertical,7)
                                                    .background(Color.white).cornerRadius(10)
                                            }.padding(.top,7)
                                            if isFinal{
                                                HStack{
                                                    Spacer()
                                                    DatePicker(selection: self.$proyecto.entrega,in: self.proyecto.inicio... ,displayedComponents: .date){
                                                        Text("")
                                                    }.onTapGesture {
                                                        self.isFinal.toggle()
                                                    }
                                                }.padding(.horizontal,-15).padding(.vertical,7)
                                                
                                            }
                                        }
                                    }
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                                //Estado
                                VStack{
                                    HStack{
                                        Text("Estado: ").padding(.trailing).foregroundColor(.green)
                                        HStack{
                                            
                                            HStack{
                                                Spacer()
                                                Button(action:{
                                                    self.isFinal = false
                                                    self.isInicio = false
                                                    self.isEstado.toggle()
                                                }){
                                                    Spacer()
                                                    Text("\(self.proyecto.estado)")
                                                        .padding(.vertical,7).padding(.horizontal,40).foregroundColor(.black)
                                                    Spacer()
                                                    Image(systemName: "chevron.down").padding(.trailing).foregroundColor(.black)
                                                }
                                                
                                            }.background(Color.white)
                                                .cornerRadius(10)
                                        }
                                    }
                                    
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                                //Observaciones
                                VStack{
                                    
                                    VStack{
                                        HStack{
                                            
                                            MultiTextField(text: self.$proyecto.mensaje, texto: self.proyecto.mensaje)
                                            .onTapGesture {
                                                    self.needTeclado = true
                                            }
                                            Text("").padding(.vertical,50)
                                            
                                        }
                                        
                                    }.background(Color.white)
                                        .cornerRadius(10)
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                            }else{
                                //Datos
                                VStack{
                                    
                                    VStack{
                                        HStack{
                                            Text("Nombre del proyecto:")
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            TextField("Nombre", text: self.$proyecto.nombre).disabled(true)
                                            Spacer()
                                        }.padding(.horizontal).padding(.vertical,7)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                    //Cliente
                                    VStack{
                                        HStack{
                                            Text("Cliente:")
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            TextField("Cliente", text: self.$proyecto.cliente).disabled(true)
                                            Spacer()
                                        }.padding(.horizontal).padding(.vertical,7)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                    //Responsable
                                    VStack{
                                        HStack{
                                            Text("Responsable:")
                                            Spacer()
                                        }
                                        
                                        HStack{
                                            TextField("Responsable", text: self.$proyecto.responsable).disabled(true)
                                            Spacer()
                                        }.padding(.horizontal).padding(.vertical,7)
                                            .background(Color.white).cornerRadius(10)
                                    }
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                                //Fechas
                                VStack{
                                    
                                    VStack{
                                        
                                        VStack{
                                            //Inicio
                                            VStack{
                                                HStack{
                                                    Text("Inicio:")
                                                    Spacer()
                                                }
                                                Spacer()
                                                HStack{
                                                    Spacer()
                                                    Text("\(self.proyecto.inicio, formatter: self.dateFormat)")                              .foregroundColor(.black)
                                                    Spacer()
                                                }.padding(.horizontal,10).padding(.vertical,7)
                                                    .background(Color.white).cornerRadius(10)
                                                
                                            }
                                            //Entrega
                                            VStack{
                                               HStack{
                                                    Text("Entrega:")
                                                    Spacer()
                                                }
                                                Spacer()
                                                HStack{
                                                    Spacer()
                                                    
                                                    Text("\(self.proyecto.entrega, formatter: self.dateFormat)")
                                                        .foregroundColor(.black)
                                                    Spacer()
                                                }.padding(.horizontal,10).padding(.vertical,7)
                                                    .background(Color.white).cornerRadius(10)
                                            }.padding(.top,7)
                                            
                                        }
                                    }
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                                
                                //Estado
                                VStack{
                                    HStack{
                                        Text("Estado: ").padding(.trailing).foregroundColor(.green)
                                        HStack{
                                            
                                            HStack{
                                                Spacer()
                                                Button(action:{
                                                    self.isFinal = false
                                                    self.isInicio = false
                                                    self.isEstado.toggle()
                                                }){
                                                    Spacer()
                                                    Text("\(self.proyecto.estado)")
                                                        .padding(.vertical,7).padding(.horizontal,40).foregroundColor(.black)
                                                    Spacer()
                                                    Image(systemName: "chevron.down").padding(.trailing).foregroundColor(.black)
                                                }
                                                
                                            }.background(Color.white)
                                                .cornerRadius(10)
                                        }
                                    }
                                    
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                                
                                //Observaciones
                                VStack{
                                    
                                    VStack{
                                        HStack{
                                            
                                            MultiTextField(text: self.$proyecto.mensaje, texto: self.proyecto.mensaje)
                                                .onTapGesture {
                                                    self.needTeclado = true
                                            }
                                            Text("").padding(.vertical,50)
                                            
                                        }
                                        
                                    }.background(Color.white)
                                        .cornerRadius(10)
                                    
                                }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            }
                            
                        }else{
                            //Datos
                            VStack{
                                
                                VStack{
                                    HStack{
                                        Text("Nombre del proyecto:")
                                        Spacer()
                                    }
                                    
                                    HStack{
                                        TextField("Nombre", text: self.$proyecto.nombre).disabled(true)
                                        Spacer()
                                    }.padding(.horizontal).padding(.vertical,7)
                                        .background(Color.white).cornerRadius(10)
                                }
                                
                                //Cliente
                                VStack{
                                    HStack{
                                        Text("Cliente:")
                                        Spacer()
                                    }
                                    
                                    HStack{
                                        TextField("Cliente", text: self.$proyecto.cliente).disabled(true)
                                        Spacer()
                                    }.padding(.horizontal).padding(.vertical,7)
                                        .background(Color.white).cornerRadius(10)
                                }
                                
                                //Responsable
                                VStack{
                                    HStack{
                                        Text("Responsable:")
                                        Spacer()
                                    }
                                    
                                    HStack{
                                        TextField("Responsable", text: self.$proyecto.responsable).disabled(true)
                                        Spacer()
                                    }.padding(.horizontal).padding(.vertical,7)
                                        .background(Color.white).cornerRadius(10)
                                }
                                
                            }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            
                            //Fechas
                            VStack{
                                
                                VStack{
                                    
                                    VStack{
                                        //Inicio
                                        VStack{
                                            HStack{
                                                Text("Inicio:")
                                                Spacer()
                                            }
                                            Spacer()
                                            HStack{
                                                Spacer()
                                                Text("\(self.proyecto.inicio, formatter: self.dateFormat)")                              .foregroundColor(.black)
                                                Spacer()
                                            }.padding(.horizontal,10).padding(.vertical,7)
                                                .background(Color.white).cornerRadius(10)
                                            
                                        }
                                        //Entrega
                                        VStack{
                                            HStack{
                                                Text("Entrega:")
                                                Spacer()
                                            }
                                            Spacer()
                                            HStack{
                                                Spacer()
                                                
                                                Text("\(self.proyecto.entrega, formatter: self.dateFormat)")
                                                    .foregroundColor(.black)
                                                Spacer()
                                            }.padding(.horizontal,10).padding(.vertical,7)
                                                .background(Color.white).cornerRadius(10)
                                        }.padding(.top,7)
                                        
                                    }
                                }
                                
                            }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                            
                            //Estado
                            VStack{
                                HStack{
                                    Text("Estado: ").padding(.trailing)
                                    HStack{
                                        
                                        HStack{
                                            Spacer()
                                            Text("\(self.proyecto.estado)")
                                                .padding(.vertical,7).padding(.horizontal,40)
                                            Spacer()
                                            
                                        }.background(Color.white)
                                            .cornerRadius(10)
                                    }
                                }
                                
                                
                            }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10).padding(.top,10)
                            
                            //Observaciones
                            VStack{
                                
                                VStack{
                                    HStack{
                                        
                                        MultiTextField(text: self.$proyecto.mensaje, texto: self.proyecto.mensaje).disabled(true)
                                        Text("").padding(.vertical,50)
                                        
                                    }
                                    
                                }.background(Color.white)
                                    .cornerRadius(10)
                                
                            }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        }
 
                    }.padding(.horizontal).padding(.top).background(Color.white)
                }.offset(y:-self.offsetTeclado)
            }
      
            if isEstado{
                GeometryReader{_ in
                    PickerDataView(estado: self.$proyecto.estado, show: self.$isEstado, datos:self.estados)
                    
                }.background(Color.black.opacity(0.65))
                    .offset(y:20)
                    .edgesIgnoringSafeArea(.top)
                    .onTapGesture {
                        withAnimation{
                            self.isEstado.toggle()
                        }
                }
            }
        }.onAppear(){
            //calculamos la altura del teclado
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                let altura = teclado.height
                if self.needTeclado{
                    self.offsetTeclado = altura
                }
            }
            
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                self.offsetTeclado = 0
            }
        }
            
        .navigationBarTitle("Proyecto",displayMode: .inline)
        .navigationBarItems(leading:
            Button(action:{
                self.show.toggle()
            }){
                HStack{
                    Image(systemName: "chevron.left")
                    Text("Proyectos")
                }
            }
            ,trailing:
            Button(action:{
                if self.isEstado{
                    self.isEstado.toggle()
                }else{
                    if self.isEdit{
                        self.actualizaProyecto()
                    }else{
                        self.isEdit.toggle()
                    }
                    
                }
                
            }){
                if isEstado{
                    Text("Aceptar")
                }else{
                    if isEdit{
                        Text("Guardar")
                    }else{
                        Text("Editar")
                    }
                }
                
                
                
            }.alert(isPresented: self.$showAlert){
                Alert(title: Text("Proyecto"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                    if self.textAlert.contains("corréctamente"){
                        self.isEdit.toggle()
                    }else{
                        self.textAlert = ""
                    }
                }))
        })
        }.navigationBarTitle("")
        .navigationBarHidden(true)
    }
}

struct EditProyectoView_Previews: PreviewProvider {
    static var previews: some View {
        EditProyectoView(show:.constant(false), proyecto: Proyecto(id: "", nombre: "", cliente: "", responsable: "", inicio: Date(), entrega: Date(), estado: "", mensaje: ""))
    }
}
