//
//  NewAgenda.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 24/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct NewAgenda: View {
    
    private let usuario = "\(UserDefaults.standard.object(forKey: "UserName") as? String ?? "") "+"(\(UserDefaults.standard.object(forKey: "UserMail") as? String ?? ""))"
    @State var empresaID = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    
    @Binding var show: Bool
    
    //No se declaran privadas para pruebas
    @State var evento: String = ""
    @State var inicio: Date = Date()
    @State var fin: Date = Date()
    @State var observaciones: String = ""
    
    @State private var textAlert: String = ""
    @State private var showAlert: Bool = false
    
    @State private var showDate: Bool = false
    @State private var showInicio: Bool = false
    @State private var showFin: Bool = false
    
    @State private var needTeclado: Bool = false
    @State private var offsetTeclado: CGFloat = 0

    
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.timeStyle = .none
        format.dateFormat = "EEEE, dd/MM/yyyy"
        return format
    }
    private var timeFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .none
        format.dateFormat = "HH:mm"
        return format
    }
    
    //Función para guardar el nuevo evento en la base de datos
    func guardaEvento(){
        let db = Firestore.firestore()
        let campos : [String: Any] = ["usuario":self.usuario, "evento": self.evento, "inicio": self.inicio, "fin":self.fin,"observaciones": self.observaciones]
        db.collection("empresas").document(self.empresaID).collection("eventos").addDocument(data: campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir el evento a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡El evento se ha registrado corréctamente!"
                self.showAlert.toggle()
            }
             
        }
    }
    
    //Función de pruebas para guardar el nuevo evento en la base de datos: es la misma función, sin generar alertas, recibiendo un clousure como parámetro)
    func guardaEvento(clousure: @escaping (DocumentReference?,Error?)->()){
        var err:Error? = nil
        var reference:DocumentReference? = nil
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["usuario":self.usuario, "evento": self.evento, "inicio": self.inicio, "fin":self.fin,"observaciones": self.observaciones]
        reference = db.collection("empresas").document(self.empresaID).collection("eventos").addDocument(data: campos){(error) in
            if error != nil{
                err = error
            }
        }
        clousure(reference,err)
    }
    
    var body: some View {
        
        VStack{
            //Cabecera
            HStack{
                Button(action:{
                    self.show.toggle()
                }){
                    Text("Cancelar").foregroundColor(.black)
                }
                Spacer()
                Text("Nuevo evento").bold()
                Spacer()
                Button(action:{
                    self.guardaEvento()
                }){
                    Text("Guardar").foregroundColor(.black)
                }.alert(isPresented: self.$showAlert){
                    Alert(title: Text("Agenda"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action: {
                        self.show.toggle()
                    }))
                }
                
            }.padding().background(Color("Fondo"))
            ScrollView{
                //Cuerpo
                VStack{
                    //Evento
                    VStack{
                        VStack{
                            HStack{
                                Text("Evento: ")
                                Spacer()
                            }
                            HStack{
                                TextField("Evento", text: self.$evento)
                                    .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                                
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                            
                        }

                    }
                    .padding()
                    .background(Color("Fondo").opacity(0.6))
                    .cornerRadius(10)
                    .padding(.top)
                    
                    //fechas
                    VStack{
                        VStack{
                            //dia
                            VStack{
                                HStack{
                                    Text("Día: ")
                                    Spacer()
                                    HStack{
                                        Spacer()
                                        Button(action:{
                                            self.showInicio = false
                                            self.showFin = false
                                            self.fin = self.inicio
                                            self.showDate.toggle()
                                        }){
                                            Text("\(self.inicio, formatter: self.dateFormat)")
                                            Image(systemName: "chevron.down")
                                        }
                                        Spacer()
                                    }.padding(.vertical,10)
                                        .background(Color.white).cornerRadius(10)
                                }
                                if self.showDate{
                                    HStack{
                                        Spacer()
                                        DatePicker(selection: self.$inicio,displayedComponents: .date){
                                            Text("")
                                        }.onTapGesture {
                                            self.showDate.toggle()
                                            self.fin = self.inicio
                                        }
                                        
                                    }.padding(.horizontal,-15).padding(.vertical,7)
                                    
                                }
                            }
                            //Horas
                            VStack{
                                //inicio
                                HStack{
                                    Text("Hora de inicio:")
                                    Spacer()
                                    HStack{
                                        Button(action:{
                                            self.showDate = false
                                            self.showFin = false
                                            self.fin = self.inicio
                                            self.showInicio.toggle()
                                            
                                        }){
                                            Text("\(self.inicio, formatter: self.timeFormat) horas. ")
                                            Image(systemName: "chevron.down")
                                            
                                        }
                                    }.padding(.horizontal,15).padding(.vertical,10)
                                        .background(Color.white).cornerRadius(10)
                                    
                                }
                                if self.showInicio{
                                    HStack{
                                        Spacer()
                                        DatePicker(selection: self.$inicio,displayedComponents: .hourAndMinute){
                                            Text("")
                                        }.onTapGesture {
                                            self.showInicio.toggle()
                                            self.fin = self.inicio
                                        }
                                        
                                    }.padding(.horizontal,-15).padding(.vertical,7)
                                    
                                }
                                //fin
                                HStack{
                                    Text("Hora final:")
                                    Spacer()
                                    HStack{
                                        Button(action:{
                                            self.showDate = false
                                            self.showInicio = false
                                            self.showFin.toggle()
                                        }){
                                            Text("\(self.fin, formatter: self.timeFormat) horas. ")
                                            Image(systemName: "chevron.down")
                                            
                                        }
                                    }.padding(.horizontal,15).padding(.vertical,10)
                                        .background(Color.white).cornerRadius(10)
                                    
                                }
                                if self.showFin{
                                    HStack{
                                        Spacer()
                                        DatePicker(selection: self.$fin,in: self.inicio...,displayedComponents: .hourAndMinute){
                                            Text("")
                                        }.onTapGesture {
                                            self.showFin.toggle()
                                        }
                                        
                                    }.padding(.horizontal,-15).padding(.vertical,7)
                                    
                                }
                            }
                        }.padding()
                    }.background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                    //Observaciones
                    VStack{
                        HStack{
                            Text("Observaciones:")
                            Spacer()
                        }
                        VStack{
                            ZStack{
                            HStack{
                                MultiTextField(text: self.$observaciones, texto: "Escriba aquí sus notas...")
                                    .onTapGesture {
                                        self.needTeclado = true
                                }
                                Spacer()
                            }.padding(-10)
                            VStack{         //Damos altura al cuadro ya que el ScrollView anula los Spacer
                                 Text("")
                                    .padding(.bottom,130)
                            }
                            }
                        }.padding()
                            .background(Color.white)
                            .cornerRadius(10)
                        
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                }.offset(y: -self.offsetTeclado).padding(.horizontal).background(Color.white)
            }
            
        }
        .onAppear(){
            //calculamos la altura del teclado
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                let altura = teclado.height
                if self.needTeclado{
                     self.offsetTeclado = altura/1.8
                }
               
            }
            
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                self.offsetTeclado = 0
            }
        }
        .navigationBarTitle("Nuevo evento",displayMode: .inline)
        
    }
}

struct NewAgenda_Previews: PreviewProvider {
    static var previews: some View {
        NewAgenda(show: .constant(true))
    }
}
