//
//  NewAnuncio.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 24/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct NewAnuncio: View {
    
    @Binding var show: Bool
    
    private let usuario = "\(UserDefaults.standard.object(forKey: "UserName") as! String) "+"(\(UserDefaults.standard.object(forKey: "UserMail") as! String))"
    var empresaID = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    
    @State private var fecha: Date = Date()
    @State private var titulo: String = ""
    @State private var anuncio: String = ""
    @State private var selected: Int = 0
    @State private var showAlert: Bool = false
    @State private var textAlert: String = ""
    
    @State private var offsetTeclado: CGFloat = 0
    @State private var needTeclado:Bool = false
    
    //Formateador de fechas
    var dateFormat: DateFormatter{
           let format = DateFormatter()
        format.dateFormat =  "dd/MM/yyyy HH:mm"
        return format
       }
   
    
    //Función para guardar el nuevo anuncio en la base de datos
    private func guardaAnuncio(){
        let prioridad = self.selected
        let db = Firestore.firestore()
        let campos : [String: Any] = ["usuario":self.usuario, "fecha": self.fecha, "titulo": self.titulo, "anuncio":self.anuncio,"prioridad":prioridad]
        db.collection("empresas").document(self.empresaID).collection("anuncios").addDocument(data: campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir el anuncio a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡El anuncio se ha registrado corréctamente!"
                self.showAlert.toggle()
            }
            
        }
    }
    
    
    var body: some View {
        
        VStack{
            //Cabecera
            HStack{
                Button(action:{
                    self.show.toggle()
                }){
                    Text("Cancelar").foregroundColor(.black)
                }
                Spacer()
                Text("Nuevo anuncio").bold()
                Spacer()
                Button(action:{
                    if self.titulo.isEmpty{
                        self.textAlert = "Error: Debe introducir un título!"
                        self.showAlert.toggle()
                    }else if self.anuncio.isEmpty{
                        self.textAlert = "Error: Debe introducir la descripción del anuncio!"
                        self.showAlert.toggle()
                    }else{
                        self.guardaAnuncio()
                    }
                    
                }){
                    Text("Guardar").foregroundColor(.black)
                }.alert(isPresented: self.$showAlert){
                Alert(title: Text("Nuevo anuncio"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                    if self.textAlert.contains("corréctamente"){
                        self.show.toggle()
                    }else{
                        self.textAlert = ""
                    }
                }))
                }
            }.padding().background(Color("Fondo"))
            
            //Cuerpo
            VStack{
                VStack{
                    //Autor
                    VStack{
                        VStack{
                            HStack(alignment: .top){
                                Text("Autor: ")
                                Spacer()
                                HStack{
                                    Text(self.usuario)
                                    Spacer()
                                }.padding(.horizontal,10)
                                
                            }
                            
                        }
                        
                    }.padding(.bottom)
                    
                    //Fecha
                    VStack{
                        VStack{
                            HStack{
                                Text("Fecha:")
                                Spacer()
                                HStack{
                                    Text("\(self.fecha,formatter:self.dateFormat)")
                                    Spacer()
                                }.padding(.horizontal,10)
                                
                            }
                            
                            
                        }
                        
                    }
                }  .padding()
                    .background(Color("Fondo").opacity(0.6))
                    .cornerRadius(10)
                    .padding(.top)

                //Título
                VStack{
                    VStack{
                        HStack{
                            Text("Título:")
                            Spacer()
                            HStack{
                                TextField("Título", text: self.$titulo)
                                .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                            }.padding(.horizontal,10).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        
                    }
                    .padding()
                    .background(Color("Fondo").opacity(0.6))
                    .cornerRadius(10)
                    
                }
                
                //Prioridad
                HStack{
                    HStack{
                        Text("Prioridad:").padding(.trailing)
                        HStack{
                            HStack{
                                Spacer()
                                
                                Picker(selection: self.$selected, label: Text("")){
                                    Text("Baja").tag(0)
                                    Text("Media").tag(1)
                                    Text("Alta").tag(2)
                                    
                                }.pickerStyle(SegmentedPickerStyle())
                                Spacer()
                                
                            }
                            
                        }
                    }
                    
                }.padding()
                 .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                
                //Observaciones
                VStack{
                    HStack{
                        Text("Mensaje:")
                        Spacer()
                        
                    }
                    VStack{
                        HStack{
                            MultiTextField(text: self.$anuncio, texto: "Escriba aquí su anuncio...")
                                .onTapGesture {
                                    self.needTeclado = true
                            }
                            Spacer()
                        }.padding(-10)
                        
                        Spacer()
                    }.padding()
                        .background(Color.white)
                        .cornerRadius(10)
                    
                }.padding() .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                
                Text("*Recuerde que los anuncios sólo podrán ser eliminados por un administrador.")
                    .opacity(0.3)
                    .padding(.vertical)
                
            }.padding(.horizontal).background(Color.white)
        }.offset(y:-self.offsetTeclado)
        .onAppear(){
            //calculamos la altura del teclado
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                let altura = teclado.height
                if self.needTeclado{
                    self.offsetTeclado = altura/1.8
                }
            }
            
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                self.offsetTeclado = 0
            }
        }
            
        
    }
    
}


struct NewAnuncio_Previews: PreviewProvider {
    static var previews: some View {
        NewAnuncio(show: .constant(false))
    }
}
