//
//  NewAusenciaView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 24/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct NewAusenciaView: View {
    
    @Binding var show: Bool
    
    @State private var showTipo: Bool = false
    @State private var isInicio: Bool = false
    @State private var isFinal: Bool = false
    @State private var showAlert: Bool = false
    @State private var tipo:String = "Vacaciones"
    @State private var inicio: Date = Date()
    @State private var final: Date = Date()
    @State private var observaciones: String = ""
    @State private var textAlert: String = ""
    @State private var offsetTeclado: CGFloat = 0
    
    @ObservedObject var usuario = GetUser(user: UserDefaults.standard.object(forKey: "UserMail") as! String)
    
    private let empresaID:String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    
    private let tipos = ["Baja médica","Visita Médica","Vacaciones","Días personales","Salida oficial"]
    
    private var dateFormatVisita:DateFormatter{
        let format = DateFormatter()
        format.dateFormat = "EEEE, dd/MM/yyyy HH:mm"
        return format
    }
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.dateFormat = "EEEE, dd/MM/yyyy"
        return format
    }
    
    
    //Función para guardar una nueva ausencia en la base de datos
    private func guardaAusencia(){
        let db = Firestore.firestore()
        let ref = db.collection("empresas").document(self.empresaID).collection("users").document(self.usuario.user.id).collection("ausencias")
        let campos : [String: Any] = ["tipo":self.tipo, "inicio": self.inicio, "final": self.final,"estado":"Pendiente","mensaje":self.observaciones]
        
        ref.addDocument(data: campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir la ausencia a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡La ausencia se ha registrado corréctamente!"
                self.showAlert.toggle()
            }
            
        }
    }
    
    var body: some View {
        ZStack{

            VStack{
                //Cabecera
                HStack{
                    Button(action:{
                        self.show.toggle()
                    }){
                        Text("Cancelar").foregroundColor(.black)
                    }
                    Spacer()
                    Text("Nueva ausencia").bold()
                    Spacer()
                    Button(action:{
                        if self.final < self.inicio{
                            self.textAlert = "Error: la fecha de finalización debe se posterior a la de inicio."
                            self.showAlert.toggle()
                        }else{
                            self.guardaAusencia()
                           
                        }
                    }){
                        Text("Guardar").foregroundColor(.black)
                    }.alert(isPresented: self.$showAlert){
                        Alert(title: Text("Nueva ausencia"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                            if self.textAlert.contains("corréctamente"){
                                self.show.toggle()
                            }else{
                                self.textAlert = ""
                            }
                        }))
                    }
                    
                }.padding().background(Color("Fondo"))
                ScrollView{
                //Cuerpo
                VStack{
                    //Tipo
                    VStack{
                        HStack{
                            Text("Ausencia:")
                            Spacer()
                            Button(action:{
                                self.showTipo.toggle()
                            }){
                                HStack{
                                    Text(self.tipo)
                                    Image(systemName: "chevron.down")
                                }
                            }
                            .padding(.horizontal,40).padding(.vertical,7)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        
                    }
                    .padding()
                    .background(Color("Fondo").opacity(0.6))
                    .cornerRadius(10)
                    
                    //fechas
                    VStack{
                        
                        VStack{
                            //Inicio
                            VStack{
                                HStack{
                                    Text("Empieza:")
                                    Spacer()
                                }
                               
                                HStack{
                                    Spacer()
                                    Button(action:{
                                        self.isInicio.toggle()
                                        self.isFinal = false
                                    }){
                                        if self.tipo.contains("Visita"){
                                            Text("\(self.inicio, formatter:self.dateFormatVisita)")
                                            Image(systemName: "chevron.down")
                                        }else{
                                            Text("\(self.inicio, formatter:self.dateFormat)")
                                            Image(systemName: "chevron.down")
                                        }
                                        
                                    }
                                    Spacer()
                                    
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                if self.isInicio{
                                    if self.tipo.contains("Visita"){
                                        HStack{
                                            DatePicker(selection: self.$inicio){
                                                Text("")
                                            }.onTapGesture {
                                                self.isInicio.toggle()
                                            }
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                    }else{
                                        HStack{
                                            DatePicker(selection: self.$inicio,displayedComponents: .date){
                                                Text("")
                                            }.onTapGesture {
                                                self.isInicio.toggle()
                                            }
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                    }
   
                                }
                            }
                            
                            //Final
                            VStack{
                                HStack{
                                    Text("Acaba:")
                                    Spacer()
                                }
                                HStack{
                                    Spacer()
                                    Button(action:{
                                        self.isFinal.toggle()
                                        self.isInicio = false
                                    }){
                                        if self.tipo.contains("Visita"){
                                            Text("\(self.final, formatter:self.dateFormatVisita)")
                                            Image(systemName: "chevron.down")
                                        }else{
                                            Text("\(self.final, formatter:self.dateFormat)")
                                            Image(systemName: "chevron.down")
                                        }
                                        
                                    }
                                    Spacer()
                                    
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                if self.isFinal{
                                    if self.tipo.contains("Visita"){
                                        HStack{
                                            DatePicker(selection: self.$final){
                                                Text("")
                                            }.onTapGesture {
                                                self.isFinal.toggle()
                                            }
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                    }else{
                                        HStack{
                                            DatePicker(selection: self.$final,in: self.inicio...,displayedComponents: .date){
                                                Text("")
                                            }.onTapGesture {
                                                self.isFinal.toggle()
                                            }
                                        }.padding(.horizontal,-15).padding(.vertical,7)
                                    }
                                    
                                }
                            }
                            
                        }.padding()
                    }.background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                    //Adjuntos
                    HStack{
                        VStack(alignment: .leading){
                            Text("Adjuntos:")
                            HStack{
                                HStack{
                                    Spacer()
                                    Text("docVisita.pdf").padding(.vertical,7).padding(.horizontal)
                                    
                                }.background(Color.white)
                                    .cornerRadius(10)
                                Button(action:{
                                    self.textAlert = "Función no disponible en la versión actual."
                                    self.showAlert.toggle()
                                }){
                                    Image(systemName: "paperclip")
                                    .resizable()
                                    .frame(width: 25, height: 25)
                                }
                                
                            }
                        }
                        
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                    // Observaciones
                    VStack{
                        HStack{
                            Text("Observaciones:")
                            Spacer()

                        }
                        VStack{
                            ZStack{
                                HStack{
                                    MultiTextField(text: self.$observaciones, texto: "Esciba sus observaciones...")
                                    Spacer()
                                }.padding(-10)
                                VStack{         //Damos altura al cuadro ya que el ScrollView anula los Spacer
                                     Text("")
                                        .padding(.bottom,130)
                                }
                               
                            }
                           
                        }   .padding()
                            .background(Color.white)
                            .cornerRadius(10)

                    }.padding() .background(Color("Fondo").opacity(0.6)).cornerRadius(10)

                }.offset(y: -self.offsetTeclado).padding(.horizontal).background(Color.white)
                    }.padding(.bottom)
            
            }
            if self.showTipo{
                GeometryReader{_ in
                    PickerDataView(estado: self.$tipo, show: self.$showTipo, datos:self.tipos)
                    
                }.background(Color.black.opacity(0.65))
                    .edgesIgnoringSafeArea(.vertical)
                    .onTapGesture {
                        withAnimation{
                            self.showTipo.toggle()
                        }
                }
            }

        }
            .onAppear(){
                //calculamos la altura del teclado
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                    let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                    let altura = teclado.height
                    self.offsetTeclado = altura/1.2
                }
                
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                    self.offsetTeclado = 0
                }
        }
        
    }
    
}

struct NewAusenciaView_Previews: PreviewProvider {
    static var previews: some View {
        NewAusenciaView(show: .constant(true))
    }
}
