//
//  NewProyecto.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 25/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct NewProyecto: View {
    //@Binding var isButton : Bool
    @Binding var show: Bool
    
    @State private var showAlert:Bool = false
    @State private var isEdit: Bool = false
    @State private var isInicio: Bool = false
    @State private var isFinal: Bool = false
    @State private var isEstado: Bool = false
    @State private var isError: Bool = false
    @State private var nombre: String = ""
    @State private var cliente: String = ""
    @State private var responsable: String = ""
    @State private var inicio: Date = Date()
    @State private var entrega: Date = Date()
    @State private var estado: String = "Inicial"
    @State private var mensaje: String = ""
    @State private var textAlert:String = ""
    
    @State private var offsetTeclado: CGFloat = 0
    @State private var needTeclado:Bool = false
    
    //Formateador de fechas
    var dateFormat: DateFormatter{
        let format = DateFormatter()
        
        format.dateStyle = .full
        format.timeStyle = .none
        return format
    }
    
    //Función para guardar el nuevo anuncio en la base de datos
    private func guardaProyecto(){
        let db = Firestore.firestore()
        let campos : [String: Any] = ["nombre":self.nombre, "cliente": self.cliente, "responsable": self.responsable, "inicio":self.inicio,"entrega":self.entrega, "estado":self.estado, "mensaje":self.mensaje]
        db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("proyectos").addDocument(data: campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al añadir el proyecto a la base de datos!"
                self.showAlert.toggle()
            }else{
                self.textAlert = "¡El proyecto se ha registrado corréctamente!"
                self.showAlert.toggle()
            }
            
        }
    }
    
    
    var body: some View {
        
        VStack{
            //Cabecera
            HStack{
                Button(action:{
                    self.show.toggle()
                }){
                    Text("Cancelar").foregroundColor(.black)
                }
                Spacer()
                Text("Nuevo proyecto").bold()
                Spacer()
                Button(action:{
                    if self.nombre.isEmpty{
                        self.isError.toggle()
                        self.textAlert = "Error: Debe introducir un nombre para el proyecto"
                        self.showAlert.toggle()
                    }else if self.cliente.isEmpty{
                        self.isError.toggle()
                        self.textAlert = "Error: Debe introducir un cliente para el proyecto"
                        self.showAlert.toggle()
                    }else if self.responsable.isEmpty{
                        self.isError.toggle()
                        self.textAlert = "Error: Debe introducir un responsable para el proyecto"
                        self.showAlert.toggle()
                    }else{
                        self.guardaProyecto()
                       
                    }
                    
                }){
                    Text("Guardar").foregroundColor(.black)
                }.alert(isPresented: self.$showAlert){
                    Alert(title: Text("Nuevo proyecto"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                        if self.textAlert.contains("corréctamente"){
                            self.show.toggle()
                        }else{
                            self.textAlert = ""
                        }
                    }))
                }
                
            }.padding().background(Color("Fondo"))
            
            ScrollView(.vertical,showsIndicators: false){
                //Cuerpo
                VStack{
                    
                    //Datos
                    VStack{
                        VStack{
                            HStack{
                                Text("Nombre del proyecto:")
                                Spacer()
                            }
                            
                            HStack{
                                TextField("Nombre", text: self.$nombre)
                                    .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,7)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        //Cliente
                        VStack{
                            HStack{
                                Text("Cliente:")
                                Spacer()
                            }
                            
                            HStack{
                                TextField("cliente", text: self.$cliente)
                                .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,7)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        //Responsable
                        VStack{
                            HStack{
                                Text("Responsable:")
                                Spacer()
                            }
                            
                            HStack{
                                TextField("Responsable", text: self.$responsable)
                                .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,7)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                    //Fechas
                    VStack{
                        
                        VStack{
                            
                            VStack{
                                //Inicio
                                VStack{
                                    HStack{
                                        Text("Inicio:")
                                        Spacer()
                                    }
                                    Spacer()
                                    HStack{
                                        Spacer()
                                        Button(action:{
                                            self.isFinal = false
                                            self.isEstado = false
                                            self.isInicio.toggle()
                                        }){
                                            
                                            Text("\(self.inicio, formatter: self.dateFormat)")
                                            Image(systemName: "chevron.down")
                                        }
                                        Spacer()
                                    }.padding(.horizontal,10).padding(.vertical,7)
                                        .background(Color.white).cornerRadius(10)
                                    
                                }
                                if isInicio{
                                    HStack{
                                        Spacer()
                                        DatePicker(selection: self.$inicio,displayedComponents: .date){
                                            Text("")
                                        }.onTapGesture {
                                            self.isInicio.toggle()
                                        }
                                        
                                    }.padding(.horizontal,-15).padding(.vertical,7)
                                    
                                }
                                
                                //Entrega
                                VStack{
                                    HStack{
                                        Text("Entrega:")
                                        Spacer()
                                    }
                                    
                                    Spacer()
                                    HStack{
                                        Spacer()
                                        Button(action:{
                                            self.isInicio = false
                                            self.isEstado = false
                                            self.isFinal.toggle()
                                        }){
                                            Text("\(self.entrega, formatter: self.dateFormat)")
                                            Image(systemName: "chevron.down")
                                        }
                                        Spacer()
                                    }.padding(.horizontal,10).padding(.vertical,7)
                                        .background(Color.white).cornerRadius(10)
                                }
                                if isFinal{
                                    HStack{
                                        Spacer()
                                        DatePicker(selection: self.$entrega,in: self.inicio... ,displayedComponents: .date){
                                            Text("")
                                        }.onTapGesture {
                                            self.isFinal.toggle()
                                        }
                                    }.padding(.horizontal,-15).padding(.vertical,7)
                                    
                                }
                            }
                        }
                        
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                    //Estado
                    VStack{
                        HStack{
                            Text("Estado: ").padding(.trailing)
                            HStack{
                                
                                HStack{
                                    Spacer()
                                    Text("\(self.estado)")
                                        .padding(.vertical,7).padding(.horizontal,40)
                                    Spacer()
                                    
                                }.background(Color.white)
                                    .cornerRadius(10)
                            }
                        }
                        
                        
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    
                    //Observaciones
                    VStack{
                       HStack{
                            Text("Observaciones:")
                            Spacer()

                        }
                        VStack{
                            ZStack{
                                HStack{
                                    MultiTextField(text: self.$mensaje, texto: "Esciba sus observaciones...")
                                    .onTapGesture {
                                            self.needTeclado = true
                                    }
                                    Spacer()
                                }.padding(-10)
                                VStack{         //Damos altura al cuadro ya que el ScrollView anula los Spacer
                                     Text("")
                                        .padding(.bottom,130)
                                }
                               
                            }
                           
                        }.padding()
                            .background(Color.white)
                            .cornerRadius(10)
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10).padding(.top)
                    
                }.offset(y:-self.offsetTeclado).padding(.horizontal).background(Color.white)
            }
        }.navigationBarTitle("Proyecto",displayMode: .inline)
        .onAppear(){
            //calculamos la altura del teclado
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                let altura = teclado.height
                if self.needTeclado{
                self.offsetTeclado = altura
                }
            }
            
            NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                self.offsetTeclado = 0
            }
        }
    }
    
}
struct NewProyecto_Previews: PreviewProvider {
    static var previews: some View {
        NewProyecto(show: .constant(true))
    }
}
