//
//  ProyectosView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 20/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct ProyectosView: View {
    
    @State private var showMenu: Bool = false
    
    @State private var showNew: Bool = false
    @State private var showEdit: Bool = false
    @State private var showYear: Bool = false
    @State private var year: String = "Todos los años"
    @State private var proyecto: Proyecto = Proyecto(id: "", nombre: "", cliente: "", responsable: "", inicio: Date(), entrega: Date(), estado: "", mensaje: "")
    
    @ObservedObject var datos = GetProyectos(empresa: UserDefaults.standard.object(forKey: "EmpresaID") as! String)

    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .medium
        format.timeStyle = .none
        return format
    }
    
    var fecha = Date()
    
    //Función para obtener un String con el año de una determinada fecha
    func getYear(date:Date)->String{
        let format = DateFormatter()
        format.dateFormat = "yyyy"
        let year = format.string(from: date)
        return year
    }
    
    var body: some View {
        ZStack{
            NavigationLink(destination: EditProyectoView(show: self.$showEdit, proyecto: self.proyecto),isActive: self.$showEdit){
                EmptyView()
            }
            
                NavigationView{
                           
                           VStack{
                            //Selección del año
                               Button(action:{
                                   self.showYear.toggle()
                               }){
                                   HStack{
                                       Text(self.year).bold()
                                       Image(systemName: "chevron.down")
                                   }
                               }
                               if self.showYear{
                                   VStack{
                                       Picker(selection: self.$year, label: Text("")){
                                           
                                           ForEach (0..<self.datos.years.count){
                                               Text(self.datos.years[$0]).tag(self.datos.years[$0])
                                           }
                                       }.offset(x: -30)
                                           .onTapGesture {
                                               self.showYear.toggle()
                                       }
                                   }.padding(.vertical, -30)
                               }
                               
                               
                               Divider()
                               
                               List{
                                   if self.year.contains("Todos"){
                                       ForEach (self.datos.proyectos){ proyecto in
                                           
                                        Button(action:{
                                            self.proyecto = proyecto
                                            self.showEdit.toggle()
                                        }){
                                            VStack{
                                                HStack{
                                                    Text("\(proyecto.nombre)").font(.title)
                                                    Spacer()
                                                }
                                                HStack{
                                                    Text("Estado: ")
                                                    if proyecto.estado == "Finalizado"{
                                                        Text("\(proyecto.estado)").foregroundColor(.green)
                                                    }else if proyecto.estado == "Cancelado"{
                                                        Text("\(proyecto.estado)").foregroundColor(.red)
                                                    }else{
                                                        Text("\(proyecto.estado)").foregroundColor(.orange)
                                                    }
                                                    Spacer()
                                                    Text("\(proyecto.inicio, formatter: self.dateFormat)")
                                                    
                                                }
                                            }
                                        }
                                               
                                           
                                       }
                                   }else{
                                    ForEach (self.datos.proyectos){ proyecto in
                                        if self.year == self.getYear(date: proyecto.inicio){
                                            Button(action:{
                                                self.proyecto = proyecto
                                                self.showEdit.toggle()
                                            }){
                                                VStack{
                                                    HStack{
                                                        Text("\(proyecto.nombre)").font(.title)
                                                        Spacer()
                                                    }
                                                    HStack{
                                                        Text("Estado: ")
                                                        if proyecto.estado == "Finalizado"{
                                                            Text("\(proyecto.estado)").foregroundColor(.green)
                                                        }else if proyecto.estado == "Cancelado"{
                                                            Text("\(proyecto.estado)").foregroundColor(.red)
                                                        }else{
                                                            Text("\(proyecto.estado)").foregroundColor(.orange)
                                                        }
                                                        Spacer()
                                                        Text("\(proyecto.inicio, formatter: self.dateFormat)")
                                                        
                                                    }
                                                }
                                            }
                                        }
                                    }
                            }
                                }
                    
                           }.navigationBarTitle("Proyectos",displayMode: .inline).padding(.vertical)
                               .navigationBarItems(leading:
                                   
                                   Button(action:{
                                       self.showMenu.toggle()
                                   }){
                                       Image (systemName: "person.crop.circle")
                                           .resizable()
                                           .frame(width: 35, height: 35)
                                   }
                                   ,trailing:
                                   
                                   Button(action:{
                                       self.showNew.toggle()
                                   }){
                                       Image (systemName: "plus")
                                           .resizable()
                                           .frame(width: 25, height: 25)
                                   }.sheet(isPresented: self.$showNew){
                                       NewProyecto(show: self.$showNew)
                               })
                           
                           
                }.offset(x: self.showMenu ? UIScreen.main.bounds.width/1.5 : 0).transition(.move(edge: self.showMenu ? .leading : .trailing))
            
            if self.showMenu{
                GeometryReader{_ in
                    MenuView(show: self.$showMenu)
                                       .offset(x: UIScreen.main.bounds.width / -4.5)
                                        .padding(.bottom,-30)
                                       .edgesIgnoringSafeArea(.top)
                                       .transition(.move(edge: .leading))
                }.background(Color.white.opacity(0.01))
                    .onTapGesture {
                            self.showMenu.toggle()
                    }
               
            }
        }
            //Mejoramos la navegacion
            .navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
}

struct ProyectosView_Previews: PreviewProvider {
    static var previews: some View {
        ProyectosView()
    }
}
