//
//  RegistroDetailView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 24/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct RegistroDetailView: View {
    
    private var dia: Dia
    private var datos: GetDescansos
    
//    init(dia: Dia){
//        self.dia = dia
//        self.datos = GetDescansos(dia: dia.id)
//    }
    init(user: String, dia: Dia){
        self.dia = dia
        self.datos = GetDescansos(user: user, dia: dia.id)
       }
    
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.timeStyle = .none
        format.dateStyle = .medium
        return format
    }
    
    private var timeFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .none
        format.dateFormat = "HH:mm:ss"
        return format
    }
    var body: some View {
        
        VStack{
            VStack {
                
                HStack{
                    Text("\(self.dia.inicio, formatter: self.dateFormat)").bold()
                }.padding()
                HStack{
                    Text("Estadísticas").bold()
                        .padding(.horizontal)
                        .padding(.vertical,7)
                    
                    Spacer()
                }.background(Color("Barras"))
                
                VStack{
                    
                    HStack {
                        Text("Horas acumuladas: ")
                        Spacer()
                        Text("\(self.datos.obtenTiempos(tiempo: self.dia.inicio.distance(to: self.dia.fin).rounded()))")
                    } .padding(.horizontal).padding(.top,7)
                    Divider()
                    HStack {
                        Text("Total descansos: ")
                        Spacer()
                        Text("\(self.datos.obtenTiempos(tiempo: self.dia.totalDescansosDia.rounded()))")
                    } .padding(.horizontal)
                    Divider()
                    HStack {
                        Text("Horas trabajadas: ")
                        Spacer()
                        Text("\(self.datos.obtenTiempos(tiempo: self.dia.inicio.distance(to: self.dia.fin).rounded() - self.dia.totalDescansosDia.rounded()))")
                    } .padding(.horizontal).padding(.bottom,7)
                }.background(Color.white)
                HStack{
                    Text("Fichajes").bold()
                        .padding(.horizontal)
                        .padding(.vertical,7)
                    
                    Spacer()
                }.background(Color("Barras"))
                VStack{
                    
                    HStack (alignment: .top) {
                        Text("Entrada:  ")
                        Spacer()
                        VStack(alignment: .trailing){
                            Text("\(self.dia.inicio, formatter: self.timeFormat) h.").bold()
                            Text("\(self.dia.locInicio)").multilineTextAlignment(.trailing).font(.footnote)
                        }
                    } .padding(.horizontal).padding(.top,7)
                    Divider()
                    HStack(alignment: .top){
                        Text("Salida:   ")
                        Spacer()
                        if self.dia.inicio == self.dia.fin{
                            Text("Sin fichaje").foregroundColor(.red)
                        }else{
                            VStack(alignment: .trailing){
                                Text("\(self.dia.fin, formatter: self.timeFormat) h.").bold()
                                Text("\(self.dia.locFin)").multilineTextAlignment(.trailing).font(.footnote)
                            }
                             
                           }
                    } .padding(.horizontal).padding(.bottom,7)
                    
                    
                }.background(Color.white)
                HStack{
                    Text("Descansos").bold()
                        .padding(.horizontal)
                        .padding(.vertical,7)
                    
                    Spacer()
                }.background(Color("Barras"))
                
                List{
                    ForEach (self.datos.descansos){ descanso in
                        HStack {
                            Text("Inicio: \(descanso.inicio, formatter: self.timeFormat) h.")
                            Spacer()
                            if descanso.inicio == descanso.fin{
                                Text("Sin fichaje").foregroundColor(.red)
                            }else{
                                Text("Final: \(descanso.fin, formatter: self.timeFormat) h.")
                            }
                            
                        }
                        
                    }
                }
            }
        }
        .navigationBarTitle("Detalle")
    }
}

struct RegistroDetailView_Previews: PreviewProvider {
    static var previews: some View {
        RegistroDetailView(user: "", dia: Dia(id: "", inicio: Date(), fin: Date(), locInicio: "", locFin: "",totalDescansosDia: 0))
    }
}
