//
//  RegistroHorarioView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 21/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct RegistroHorarioView: View {
    
    @ObservedObject var datos: GetJornadas
    
    @State private var showMeses: Bool = false
    @State private var mes: String = "Todos los meses"
    
    private var userName:String = ""
    private var userId: String = UserDefaults.standard.object(forKey: "UserID") as! String
    
    init(){
        datos = GetJornadas()
    }
    
    init(user:String, username: String){
        self.datos = GetJornadas(user: user)
        self.userName = username
        self.userId = user
    }
    
    private var dateFormat:DateFormatter{
        let format = DateFormatter()
        format.timeStyle = .none
        format.dateFormat = "dd/MM/yyyy"
        return format
    }
    
    private var timeFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .none
        format.dateFormat = "HH:mm"
        return format
    }
    
    //Función para obtener un String con el mes de una determinada fecha
    private func getDate(date:Date)->String{
        let format = DateFormatter()
        format.dateFormat = "MMMM yyyy"
        let mes = format.string(from: date)
        return mes
    }
    //Función que obtiene el intervalo correspondiente al tiempo total o mensual de descansos
    private func obtenTotalDescansos() -> Double{
        var intervalo: Double = 0
        if self.mes.contains("Todos"){
            for dia in self.datos.jornadas{
                intervalo = intervalo + dia.totalDescansosDia
            }
        }else{
            for dia in self.datos.jornadas{
                if getDate(date: dia.inicio).isEqual(self.mes){
                    intervalo = intervalo + dia.totalDescansosDia
                }
            }
        }
        
        return intervalo
    }
    
    //Función que obtiene el intervalo correspondiente al tiempo total o mensual de trabajo
    private func obtenTotalTrabajado() -> Double{
        var intervalo: Double = 0
        if self.mes.contains("Todos"){
            for dia in self.datos.jornadas{
                intervalo = intervalo + dia.inicio.distance(to: dia.fin)
            }
        }else{
            for dia in self.datos.jornadas{
                if getDate(date: dia.inicio).isEqual(self.mes){
                    intervalo = intervalo + dia.inicio.distance(to: dia.fin)
                }
            }
        }
        
        return intervalo
    }
    
    var body: some View {
        
        VStack {
            //Seleccion del mes
            Button(action:{
                self.showMeses.toggle()
            }){
                HStack{
                    Text(self.mes).bold()
                    Image(systemName: "chevron.down").rotationEffect(.degrees(self.showMeses ? 180:0))
                }
            }.padding(.vertical,7)
            if self.showMeses{
                //Muestra el picker
                VStack{
                    Picker(selection: self.$mes, label: Text("")){
                        
                        ForEach (0..<self.datos.meses.count){
                            Text(self.datos.meses[$0]).tag(self.datos.meses[$0])
                        }
                    }.offset(x: -30)
                        .onTapGesture {
                            self.showMeses.toggle()
                    }
                }.padding(.vertical, -30)
            }
            //Estadísticas
            HStack{
                Text("Estadísticas").bold()
                    .padding(.horizontal)
                    .padding(.vertical,7)
                
                Spacer()
            }.background(Color("Barras"))
            
            VStack{
                
                HStack {
                    Text("Horas acumuladas: ")
                    Spacer()
                    Text("\(self.datos.obtenTiempos(tiempo: self.obtenTotalTrabajado().rounded())) horas")
                } .padding(.horizontal).padding(.top,7)
                Divider()
                HStack {
                    Text("Total descansos: ")
                    Spacer()
                    Text("\(self.datos.obtenTiempos(tiempo: self.obtenTotalDescansos().rounded())) horas")
                } .padding(.horizontal)
                Divider()
                HStack {
                    Text("Horas trabajadas: ")
                    Spacer()
                    Text("\(self.datos.obtenTiempos(tiempo: self.obtenTotalTrabajado().rounded() - self.obtenTotalDescansos().rounded())) horas")
                } .padding(.horizontal)
            }.background(Color.white)
            HStack{
                Text("Fichajes").bold()
                    .padding(.horizontal)
                    .padding(.vertical,7)
                
                Spacer()
            }.background(Color("Barras"))
            //Lista de fichajes
            List{
                if self.mes.contains("Todos"){
                    ForEach (self.datos.jornadas){ dia in
                        NavigationLink(destination: RegistroDetailView(user: self.userId, dia: dia)){
                            HStack{
                                Text("\(dia.inicio, formatter: self.dateFormat)")
                                Spacer()
                                if dia.inicio == dia.fin{
                                    Text("de \(dia.inicio, formatter: self.timeFormat) a -:--:-- h").foregroundColor(.red)
                                    .padding(.trailing)
                                }else{
                                    Text("de \(dia.inicio, formatter: self.timeFormat) a \(dia.fin, formatter: self.timeFormat) h")
                                    .padding(.trailing)
                                }
                                
                            }
                        }
                    }
                }else{
                    ForEach (self.datos.jornadas){ dia in
                        if self.getDate(date: dia.inicio).isEqual(self.mes){
                            NavigationLink(destination: RegistroDetailView(user:self.userId, dia: dia)){
                                HStack{
                                    Text("\(dia.inicio, formatter: self.dateFormat)")
                                    Spacer()
                                    if dia.inicio == dia.fin{
                                        Text("de \(dia.inicio, formatter: self.timeFormat) a -:--:-- h").foregroundColor(.red)
                                            .padding(.trailing)
                                    }else{
                                        Text("de \(dia.inicio, formatter: self.timeFormat) a \(dia.fin, formatter: self.timeFormat) h")
                                            .padding(.trailing)
                                    }
                                }
                            }
                        }
                        
                    }
                }
                
                
            }
        }
        .navigationBarTitle(self.userName)
        .navigationBarHidden(false)
    }
}

struct RegistroHorarioView_Previews: PreviewProvider {
    static var previews: some View {
        RegistroHorarioView(user: "", username: "")
    }
}
