//
//  TablonView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 20/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct TablonView: View {
    
    @State var showMenu: Bool = false
    @State private var showNew: Bool = false
    
    @ObservedObject var datos = GetAnuncios()
    
    var body: some View {
        ZStack{
            NavigationView{
                VStack{
                    ScrollView(.vertical,showsIndicators: false){
                        VStack{
                            ForEach (self.datos.anuncios){ anuncio in
                                AnuncioView(datos: anuncio).padding(.top,5)
                            }
                            //Damos amplitud al ScrollView
                            HStack{
                                Spacer()
                            }
                        }
                        
                    }
                    
                }
                    
                .background(Color.gray)
                .navigationBarTitle("Tablón de Anuncios", displayMode: .inline)
                .navigationBarItems(leading:
                    Button(action:{
                        self.showMenu.toggle()
                    }){
                        Image (systemName: "person.crop.circle")
                            .resizable()
                            .frame(width: 35, height: 35)
                    }, trailing:
                    Button(action:{
                        self.showNew.toggle()
                    }){
                        Image (systemName: "plus")
                            .resizable()
                            .frame(width: 25, height: 25)
                    }.sheet(isPresented: self.$showNew){
                        NewAnuncio(show:self.$showNew)
                })
                
                
            }.offset(x: self.showMenu ? UIScreen.main.bounds.width/1.5 : 0).transition(.move(edge: self.showMenu ? .leading : .trailing))
            
            //Menu
            if self.showMenu{
                GeometryReader{_ in
                    MenuView(show: self.$showMenu)
                        .offset(x: UIScreen.main.bounds.width / -4.5)
                        .edgesIgnoringSafeArea(.top)
                        .padding(.bottom,-30)
                        .transition(.move(edge: .leading))
                }.background(Color.white.opacity(0.01))
                    .onTapGesture {
                        self.showMenu.toggle()
                }
                
            }
        }
            
            //Mejoramos la navegacion
            .navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
}

struct TablonView_Previews: PreviewProvider {
    static var previews: some View {
        TablonView()
    }
}
