//
//  MenuView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 20/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseAuth
import MessageUI

struct MenuView: View {
    @Binding var show: Bool
    
    @State private var showUsers:Bool = false
    @State private var showPerfil:Bool = false
    @State private var showEmpresa:Bool = false
    @State private var showLogin:Bool = false
    @State private var showGeneradorQR: Bool = false
    @State private var showAlert:Bool = false
    @State private var textAlert:String = ""
    
    var company:String = UserDefaults.standard.object(forKey: "Empresa") as! String
    var user:String = UserDefaults.standard.object(forKey: "UserMail") as! String
    var userName:String = UserDefaults.standard.object(forKey: "UserName") as! String
    var isAdmin:Bool = UserDefaults.standard.object(forKey: "isAdmin") as! Bool
    
    private let mailComposeDelegate = mailDelelgate()
    
    var body: some View {
        ZStack{
            NavigationLink(destination: UsuarioView(show:self.$showUsers,showMenu:self.$show), isActive: self.$showUsers){
                EmptyView()
            }
            NavigationLink(destination: PerfilView(show:self.$showPerfil,showMenu:self.$show, datos:GetUser(user: self.user)), isActive: self.$showPerfil){
                EmptyView()
            }
            NavigationLink(destination: EmpresaDetailView(show:self.$showEmpresa,showMenu:self.$show), isActive: self.$showEmpresa){
                EmptyView()
            }
            NavigationLink(destination: LoginView(), isActive: self.$showLogin){
                EmptyView()
            }
            NavigationLink(destination: GeneradorQRView(show: self.$showGeneradorQR, showMenu: self.$show), isActive: self.$showGeneradorQR){
                EmptyView()
            }
            VStack{
                    VStack{
                      Spacer()
                        ZStack{
                        //Cerrar - Boton superior
                            VStack{
                                HStack{
                                    Spacer()
                                    Button(action:{
                                        self.show.toggle()
                                    }){
                                        Image(systemName: "arrow.left.to.line")
                                            .resizable()
                                            .frame(width: 25, height: 25)
                                            
                                    }.padding(.bottom,85)
                                }
                              
                            }
                        
                        //Imagen de Usuario
                        Image(systemName: "person.crop.circle")
                            .resizable()
                            .frame(width: 100, height: 100)
                            .foregroundColor(.blue)
                        }
                        
                        if self.userName.isEmpty{
                            Text(self.user)
                                //.font(.title)
                                .foregroundColor(.blue)
                        }else{
                            Text(self.userName)
                                .font(.title)
                                .foregroundColor(.blue)
                        }
                        
                        Text(self.company)
                            .foregroundColor(.blue)
                        
                        //Opciones
                        VStack{
                            if self.isAdmin == false{
                                Text("")
                                Text("")
                            }
                            //Perfil
                            VStack{
                                HStack{
                                    Button(action:{
                                        self.showPerfil.toggle()
                                    }){
                                        Image(systemName: "person.fill").frame(width: 20, height: 20)
                                        Text("Perfil")
                                        Spacer()
                                        Image(systemName: "chevron.right")
                                        
                                    }
                                }
                                Divider()
                            }
                            //Usuarios
                            if self.isAdmin{
                                VStack{
                                    HStack{
                                        Button(action:{
                                            self.showUsers.toggle()

                                        }){
                                            Image(systemName: "person.2.fill").frame(width: 20, height: 20)
                                            Text("Usuarios")
                                            Spacer()
                                            Image(systemName: "chevron.right")
                                            
                                        }
                                        
                                    }
                                    Divider()
                                }
                            }else{
                                Text("")
                            }
                            //Empresa
                            VStack{
                                HStack{
                                    Button(action:{
                                        self.showEmpresa.toggle()
                                    }){
                                        Image(systemName: "house.fill").frame(width: 20, height: 20)
                                        Text("Empresa")
                                        Spacer()
                                        Image(systemName: "chevron.right")
                                        
                                    }
                                }
                                Divider()
                            }
                            //Generador de códigos
                            if self.isAdmin{
                                VStack{
                                    Text("").padding()
                                    HStack{
                                        Button(action:{
                                            self.showGeneradorQR.toggle()
                                        }){
                                            Image(systemName: "qrcode").frame(width: 20, height: 20)
                                            Text("Generador QR")
                                            Spacer()
                                            Image(systemName: "chevron.right")
                                            
                                        }
                                    }
                                    Divider()
                                }
                            }else{
                                Text("").padding()
  
                            }
                            
                            //Contacto
                            VStack{
                                Text("").padding()
                                HStack{
                                    Button(action:{
                                        self.enviarEmail()
                                    }){
                                        Image(systemName: "envelope.fill").frame(width: 20, height: 20)
                                        Text("Contacto")
                                        Spacer()
                                        Image(systemName: "chevron.right")
                                        
                                    }
                                }
                                Divider()
                            }
                            if self.isAdmin == false{
                                Text("").padding()
                            }
                            //LogOut
                            HStack{
                                Button(action:{
                                    if UserDefaults.standard.bool(forKey: "isStarted") == true{
                                        self.showAlert.toggle()
                                    }else{
                                        try! Auth.auth().signOut()
                                        self.showLogin.toggle()
                                    }
                                }){
                                    Spacer()
                                    Text("Salir")
                                    Image(systemName: "arrow.right.circle.fill")
                                        .resizable()
                                        .frame(width: 25, height: 25)
                                }.alert(isPresented: self.$showAlert){
                                    Alert(title: Text("LogOut"), message: Text("Tiene una jornada iniciada, finalícela antes de salir."), dismissButton: .default(Text("Aceptar"), action:{
                                        self.show.toggle()
                                    }))
                                }
                            }.padding(.top,20)
                        }.padding(.top).padding(.bottom,40)
                        Text("ControlWork v1.0.0").padding(.bottom).font(.custom("Arial", size: 16))
                        Spacer()
                    }.padding()

                
                
                
            }.padding(.horizontal,10).padding(.leading,30)
            
            
        }.background(Color("Fondo"))
            .cornerRadius(10)
            .padding(.horizontal,40)
            //.padding(.top,30)
            .edgesIgnoringSafeArea(.top)
            .navigationBarTitle("")
            .navigationBarHidden(true)
        //.transition(.move(edge: self.show ? .leading:.trailing))
        //.transition(.slide)
        //.animation(.default)
        
    }
    
}
extension MenuView{
    
    class mailDelelgate: NSObject, MFMailComposeViewControllerDelegate {
        func mailComposeController(_ controller: MFMailComposeViewController, didFinishWith result: MFMailComposeResult, error: Error?) {
            controller.dismiss(animated: true, completion: nil)
            
        }
    }
    
    func enviarEmail(){
        if MFMailComposeViewController.canSendMail() {
            let vc = UIApplication.shared.windows.filter {$0.isKeyWindow}.first?.rootViewController
            let mail = MFMailComposeViewController()
            mail.setSubject("Contacto ControlWork")
            mail.setToRecipients(["eperianes@uoc.edu"])
            mail.setMessageBody("Tengo la siguiente consulta sobre ControlWork: \n", isHTML: false)
            mail.mailComposeDelegate = mailComposeDelegate
            vc?.present(mail, animated: true, completion: nil)
        }else{
            //print("Error al enviar mensaje")
            self.textAlert = "¡Error al enviar mensaje!"
            self.showAlert.toggle()
        }
    }
}
struct MenuView_Previews: PreviewProvider {
    static var previews: some View {
        MenuView(show: .constant(false), company: "empresa", user: "usuario", userName: "edu", isAdmin: true)
    }
}
