//
//  NewUserView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 25/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore
import FirebaseAuth

struct NewUserView: View {
    
    @Binding var show: Bool
    @State private var showAlert = false
    @State private var textAlert = ""
    
    @State private var rol: String = ""
    @State private var isAdmin: Bool = false
    @State private var nombre: String = ""
    @State private var apellidos: String = ""
    @State private var movil: String = ""
    @State private var telefono: String = ""
    @State private var mail: String = ""
    @State private var code: String = ""
    @State private var needTeclado: Bool = false
    @State private var offsetTeclado: CGFloat = 0
    
    @State private var selected: Int = 0
    
    //Función que retorna un password aleatorio para el nuevo usuario
   func generaPassword() -> String{
        let base = ["a","b","c","d","e","f","g","h","I","J","K","L","M","N","O","P","Q","0","1","2","3","4","5","6","7","8","9"]
        var pass: String = ""
        var i = 0
        while i < 6 {
            pass = pass + base.randomElement()!
            i+=1
        }
        print(pass)
        return pass
    }
    
    //Función para añadir un datos de usuario en la base de datos
    private func guardaUsuario(){
        if selected == 1{
            self.isAdmin = true
        }else{
            self.isAdmin = false
        }
        Auth.auth().createUser(withEmail: self.mail, password: self.generaPassword()){ (user, error) in
            if user != nil{
               let db = Firestore.firestore()
               let campos : [String: Any] = ["isAdmin":self.isAdmin, "nombre": self.nombre, "apellidos": self.apellidos, "movil":self.movil,"telefono":self.telefono,"mail":self.mail, "codigo": self.code]
               db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("users").addDocument(data: campos){(error) in
                          if error != nil{
                              self.textAlert = "¡Error al añadir al usuario a la base de datos!"
                              self.showAlert.toggle()
                          }else{
                              self.textAlert = "¡El usuario se ha registrado corréctamente!"
                              self.showAlert.toggle()
                          }
                          
                      }
            }else{
                //if (error?.localizedDescription) != nil{
                if let error = error?.localizedDescription{
                    if error.contains("another account"){
                        self.textAlert = "¡e-mail ya registrado!"
                        
                    }else{
                        self.textAlert = "¡e-mail incorrecto!"
                        
                    }
                    
                    //print ("Error al escribir en la base de datos",error)
                }else{
                    self.textAlert = "¡Error en el registro!"
                    //print ("Error en el sistema de registro")
                }
            }
        
        }
    }
    
    
    var body: some View {
        
        NavigationView{
            VStack{
                
                //Cuerpo
                VStack{
                    
                    //Empresa
                    HStack{
                        
                        Text("Empresa:").padding(.trailing)
                        HStack{
                            
                            HStack{
                                Spacer()
                                Text(UserDefaults.standard.object(forKey: "Empresa") as! String).padding(.vertical,10)
                                Spacer()
                                
                            }.background(Color.white)
                                .cornerRadius(10)
                        }
                        
                        
                    }.padding()
                        .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        .padding(.top)
                    
                    //Rol
                    HStack{
                        HStack{
                            Text("Rol:         ").padding(.trailing)
                            HStack{
                                HStack{
                                    Spacer()
                                    
                                    Picker(selection: self.$selected, label: Text("")){
                                        Text("Usuario").tag(0)
                                        Text("Administrador").tag(1)
                                        
                                        
                                    }.pickerStyle(SegmentedPickerStyle())
                                    Spacer()
                                    
                                }
                                
                            }
                        }
                        
                    }.padding()
                     .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        
                    
                    
                    //Datos
                    VStack{
                        
                        //Nombre
                        HStack{
                            Text("Nombre:  ")
                            HStack{
                                TextField("Nombre", text: self.$nombre)
                                .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        //Apellidos
                        
                        HStack{
                            Text("Apellidos:")
                            HStack{
                                TextField("Apellidos", text: self.$apellidos)
                                .onTapGesture {
                                        self.needTeclado = false
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        
                        //Teléfono
                        
                        HStack{
                            Text("Móvil:       ")
                            HStack{
                                TextField("Móvil", text: self.$movil)
                                    .onTapGesture {
                                        self.needTeclado = true
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        //Teléfono
                        
                        HStack{
                            Text("Teléfono:  ")
                            HStack{
                                TextField("Teléfono", text: self.$telefono)
                                .onTapGesture {
                                        self.needTeclado = true
                                }
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        //Correo
                        VStack{
                            HStack{
                                Text("Correo electrónico:")
                                Spacer()
                            }.padding(.top,10)
                            
                            HStack{
                                TextField("e-mail", text: self.$mail)
                                    .onTapGesture {
                                            self.needTeclado = true
                                    }
                                .textContentType(.emailAddress)
                                .keyboardType(.emailAddress)
                                .autocapitalization(.none)
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                        }
                        
                        //Código
                        VStack{
                            HStack{
                                Text("Código:")
                                Spacer()
                            }.padding(.top,10)
                            
                            HStack{
                                TextField("Código", text: self.$code)
                                    .onTapGesture {
                                            self.needTeclado = true
                                    }
                                .autocapitalization(.none)
                                Spacer()
                            }.padding(.horizontal).padding(.vertical,10)
                                .background(Color.white).cornerRadius(10)
                            HStack{
                               Text("*Únicamente para usuarios con movilidad")
                                .font(.footnote)
                                Spacer()
                            }
                            
                        }.padding(.bottom)
  
                    }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
 
                }.padding(.horizontal).background(Color.white)
                Spacer()
            } .navigationBarTitle("Nuevo usuario")
                .navigationBarItems(leading:
                    Button(action:{
                        self.show.toggle()
                    }){
                        Text("Cancelar")
                        
                    },trailing:
                    Button(action:{
                        if self.mail.isEmpty{
                            self.textAlert = "¡La dirección de correo electrónico es obligatoria!"
                            self.showAlert.toggle()
                        }else{
                            self.guardaUsuario()
                            
                        }
                    }){
                        Text("Guardar")
                        
                }).alert(isPresented: self.$showAlert){
                    Alert(title: Text("Nuevo usuario"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                        if self.textAlert.contains("corréctamente"){
                            self.show.toggle()
                        }else{
                            self.textAlert = ""
                        }
                    }))
            }
            
            
        }.offset(y:-self.offsetTeclado)
        .onAppear(){
                //calculamos la altura del teclado
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                    let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                    let altura = teclado.height
                    if self.needTeclado{
                        self.offsetTeclado = altura/1.2
                    }
                  
                }
                
                NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                    self.offsetTeclado = 0
                }
        }
            //Mejoramos la navegacion
            .navigationBarHidden(true)
            .navigationBarTitle("")
    }
}


struct NewUserView_Previews: PreviewProvider {
    static var previews: some View {
        NewUserView(show:.constant(false))
    }
}
