//
//  PerfilView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 14/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct PerfilView: View {
    @Binding var show: Bool
    @Binding var showMenu: Bool
    
    let empresa: String = UserDefaults.standard.object(forKey: "Empresa") as! String
    let empresaID: String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    
    @State private var isEdit:Bool = false
    @State private var showAlert = false
    @State private var hayError = false
    @State private var textAlert = ""
    @State private var offsetTeclado: CGFloat = 0
    @State private var needTeclado = false
    
    @ObservedObject var datos: GetUser
    
    //Función para actualizar los datos de usuario en la base de datos
    private func actualizaUsuario(){
        let user = self.datos.user
        let db = Firestore.firestore()
        let campos : [String: Any] = ["nombre":user.nombre , "apellidos": user.apellidos, "movil":user.movil, "telefono": user.telefono,"codigo":user.codigo]
        db.collection("empresas").document(self.empresaID).collection("users").document(user.id).updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al actualizar usuario!"
                self.showAlert.toggle()
            }else{
                if self.datos.user.nombre.isEmpty == false{
                    UserDefaults.standard.set(user.nombre, forKey: "UserName")
                }
                UserDefaults.standard.set(user.codigo, forKey: "UserCode")
                self.textAlert = "¡Usuario actualizado corréctamente!"
                self.showAlert.toggle()
            }
        }
    }
    

    var body: some View {
        
        NavigationView{
            VStack{
                //Cuerpo
                VStack{
                    
                    //Empresa
                    HStack{
                        
                        Text("Empresa:").padding(.trailing)

                            HStack{
                                Spacer()
                                Text(self.empresa).padding(.vertical,10).padding(.horizontal,40)
                                Spacer()
                                
                            }.background(Color.white)
                                .cornerRadius(10)

                    }.padding()
                        .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        .padding(.top)
                    //Rol
                    HStack{
                        HStack{
                            Text("Rol:         ").padding(.trailing)
                            HStack{
                                
                                HStack{
                                    Spacer()
                                    if self.datos.user.isAdmin{
                                         Text("Administrador").padding(.vertical,10).padding(.horizontal,40)
                                    }else{
                                         Text("Usuario").padding(.vertical,10).padding(.horizontal,40)
                                    }
                                   
                                    Spacer()
                                   
                                    
                                }.background(Color.white)
                                    .cornerRadius(10)
                            }
                        }
                        
                    }.padding()
                        .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        .padding(.top)
                    
                    
                    //Datos
                    //Si editamos
                    if isEdit{
                        VStack{
                            
                            //Nombre
                            HStack{
                                Text("Nombre:  ").foregroundColor(.green)
                                HStack{
                                    TextField("Nombre", text: self.$datos.user.nombre)
                                        .onTapGesture {
                                            self.needTeclado = false
                                    }
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Apellidos
                            HStack{
                                Text("Apellidos:").foregroundColor(.green)
                                HStack{
                                    TextField("Apellidos", text: self.$datos.user.apellidos)
                                    .onTapGesture {
                                            self.needTeclado = false
                                    }
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Móvil
                            HStack{
                                Text("Móvil:       ").foregroundColor(.green)
                                HStack{
                                    TextField("Móvil", text: self.$datos.user.movil)
                                    .onTapGesture {
                                            self.needTeclado = true
                                    }
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Teléfono
                            HStack{
                                Text("Teléfono:  ").foregroundColor(.green)
                                HStack{
                                    TextField("Teléfono", text: self.$datos.user.telefono)
                                    .onTapGesture {
                                            self.needTeclado = true
                                    }
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
 
                            //Correo
                            VStack{
                                HStack{
                                    Text("Correo electrónico:")
                                    Spacer()
                                }.padding(.vertical,10)
                                
                                HStack{
                                    Text(self.datos.user.mail)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Código
                            VStack{
                                HStack{
                                    if self.datos.user.isAdmin{
                                        Text("Código:").foregroundColor(.green)
                                    }else{
                                        Text("Código:")
                                    }
                                    
                                    Spacer()
                                }.padding(.top,10)
                                
                                HStack{
                                    if self.datos.user.isAdmin{
                                        TextField("Código", text: self.$datos.user.codigo)
                                            .onTapGesture {
                                                    self.needTeclado = true
                                            }
                                        .autocapitalization(.none)
                                    }else{
                                        SecureField("Código", text: self.$datos.user.codigo).disabled(true)
                                        .autocapitalization(.none)
                                    }
                                    
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                HStack{
                                   Text("*Únicamente para usuarios con movilidad")
                                    .font(.footnote)
                                    Spacer()
                                }
                                
                            }.padding(.bottom)
                            
                            
                        }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    }else{
                        VStack{
                            
                            //Nombre
                            HStack{
                                Text("Nombre:  ")
                                HStack{
                                    TextField("Nombre", text: self.$datos.user.nombre).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Apellidos
                            HStack{
                                Text("Apellidos:")
                                HStack{
                                    TextField("Apellidos", text: self.$datos.user.apellidos).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Móvil
                            
                            HStack{
                                Text("Móvil:       ")
                                HStack{
                                    TextField("Móvil", text: self.$datos.user.movil).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Teléfono
                            
                            HStack{
                                Text("Teléfono:  ")
                                HStack{
                                    TextField("Teléfono", text: self.$datos.user.telefono).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }

                            //Correo
                            VStack{
                                HStack{
                                    Text("Correo electrónico:")
                                    Spacer()
                                }.padding(.vertical,10)
                                
                                HStack{
                                    Text(self.datos.user.mail)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Código
                            VStack{
                                HStack{
                                    Text("Código:")
                                    Spacer()
                                }.padding(.top,10)
                                
                                HStack{
                                    SecureField("Código", text: self.$datos.user.codigo).disabled(true)
                                    .autocapitalization(.none)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                HStack{
                                   Text("*Únicamente para usuarios con movilidad")
                                    .font(.footnote)
                                    Spacer()
                                }
                                
                            }.padding(.bottom)
                            
                        }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    }
                    
                    
                }.padding(.horizontal).background(Color.white)
                Spacer()
            }.onAppear(){
                    //calculamos la altura del teclado
                    NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillShowNotification, object: nil, queue: .main) { (notification) in
                        let teclado = notification.userInfo![UIResponder.keyboardFrameEndUserInfoKey] as! CGRect
                        let altura = teclado.height
                        if self.needTeclado{
                              self.offsetTeclado = altura/1.2
                        }
                      
                    }
                    
                    NotificationCenter.default.addObserver(forName: UIResponder.keyboardWillHideNotification, object: nil, queue: .main) { (notification) in
                        self.offsetTeclado = 0
                    }
            }
            .navigationBarTitle("Perfil de usuario")
                .navigationBarItems(leading:
                    Button(action:{
                            self.showMenu.toggle()
                            self.show.toggle()
                    }){
                        
                        Text("Salir")
                        
                        
                    },trailing:
                    Button(action:{
                        if self.isEdit{
                            self.actualizaUsuario()

                        }else{
                            self.isEdit.toggle()
                        }
                        
                    }){
                        if self.isEdit{
                            Text("Guardar")
                        }else{
                            Text("Editar")
                        }
                        
                }).alert(isPresented: self.$showAlert){
                    Alert(title: Text("Actualizar usuario"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                        self.showMenu.toggle()
                        self.show.toggle()
                        
                        
                    }))
            }
            
            
        }.offset(y:-self.offsetTeclado)
            //Mejoramos la navegacion
            .navigationBarHidden(true)
            .navigationBarTitle("")
    }
}


struct PerfilView_Previews: PreviewProvider {
    static var previews: some View {
        PerfilView(show: .constant(false),showMenu: .constant(false), datos: GetUser(user:"eperianes@uno.com"))
    }
}
