//
//  UserDetailView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 15/04/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct UserDetailView: View {
    
    //@Binding var show: Bool
    
        
    @State private var isEdit:Bool = false
    @State private var showAlert: Bool = false
    @State private var textAlert: String = ""
    @State private var selected: Int = 0
    
    @ObservedObject var datos: GetUser
    
    //Función para actualizar los datos de usuario en la base de datos
    private func actualizaUsuario(){
        var user = self.datos.user
        if self.selected == 0{
            user.isAdmin = false
        }else{
            user.isAdmin = true
        }
        let db = Firestore.firestore()
        let campos : [String: Any] = ["isAdmin": user.isAdmin,"nombre":user.nombre , "apellidos": user.apellidos, "movil":user.movil, "telefono": user.telefono, "codigo":user.codigo]
        db.collection("empresas").document(UserDefaults.standard.object(forKey: "EmpresaID") as! String).collection("users").document(user.id).updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al actualizar usuario!"
                self.showAlert.toggle()
                //print(error!.localizedDescription)
            }else{
                self.textAlert = "¡Usuario actualizado corréctamente!"
                self.showAlert.toggle()
            }
        }
    }
    
    
    var body: some View {
        
       
            VStack{
                
                //Cuerpo
                VStack{
                    
                    //Empresa
                    HStack{
                        
                        Text("Empresa:").padding(.trailing)
                        HStack{
                            
                            HStack{
                                Spacer()
                                Text(UserDefaults.standard.object(forKey: "Empresa") as! String).padding(.vertical,10)
                                Spacer()
                                
                            }.background(Color.white)
                                .cornerRadius(10)
                        }
                        
                        
                    }.padding()
                        .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        .padding(.top)
                    //Rol
                    HStack{
                        HStack{
                            if isEdit{
                                if self.datos.user.isAdmin == false{
                                    Text("Rol:         ").foregroundColor(.green).padding(.trailing)
                                }else{
                                    Text("Rol:         ").padding(.trailing)
                                }
                            }else{
                                 Text("Rol:         ").padding(.trailing)
                            }
                           
                            HStack{
                                if self.isEdit{
                                    if self.datos.user.isAdmin{
                                        HStack{
                                            Spacer()
                                            Text("Administrador").padding(.vertical,10).padding(.horizontal,40)
                                            Spacer()
                                        }.background(Color.white)
                                        .cornerRadius(10)
                                    }else{
                                   
                                            Picker(selection: self.$selected, label: Text("")){
                                                Text("Usuario").tag(0)
                                                Text("Administrador").tag(1)
                                            }.pickerStyle(SegmentedPickerStyle())
  
                                    }
                                }else{
                                    HStack{
                                        Spacer()
                                        if self.datos.user.isAdmin{
                                            Text("Administrador").padding(.vertical,10).padding(.horizontal,40)
                                        }else{
                                            Text("Usuario").padding(.vertical,10).padding(.horizontal,40)
                                        }
                                        
                                        Spacer()
                                    }.background(Color.white)
                                    .cornerRadius(10)
                                }
                                
                            }
                        }
                        
                    }.padding()
                        .background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                        .padding(.top)

                    //Datos
                    //Si editamos
                    if isEdit{
                        VStack{
                            
                            //Nombre
                            HStack{
                                Text("Nombre:  ").foregroundColor(.green)
                                HStack{
                                    TextField("Nombre", text: self.$datos.user.nombre)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Apellidos
                            HStack{
                                Text("Apellidos:").foregroundColor(.green)
                                HStack{
                                    TextField("Apellidos", text: self.$datos.user.apellidos)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }

                            //Móvil
                            HStack{
                                Text("Móvil:       ").foregroundColor(.green)
                                HStack{
                                    TextField("Móvil", text: self.$datos.user.movil)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Teléfono
                            HStack{
                                Text("Teléfono:  ").foregroundColor(.green)
                                HStack{
                                    TextField("Teléfono", text: self.$datos.user.telefono)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }

                            //Correo
                            VStack{
                                HStack{
                                    Text("Correo electrónico:")
                                    Spacer()
                                }.padding(.vertical,10)
                                
                                HStack{
                                    Text(self.datos.user.mail)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Código
                            VStack{
                                HStack{
                                    Text("Código:").foregroundColor(.green)
                                    Spacer()
                                }.padding(.top,10)
                                
                                HStack{
                                    TextField("Código", text: self.$datos.user.codigo)
                                        .autocapitalization(.none)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                HStack{
                                    Text("*Únicamente para usuarios con movilidad")
                                        .font(.footnote)
                                    Spacer()
                                }
                                
                            }.padding(.bottom)
                             
                        }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    }else{
                        VStack{
                            
                            //Nombre
                            HStack{
                                Text("Nombre:  ")
                                HStack{
                                    TextField("Nombre", text: self.$datos.user.nombre).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Apellidos
                            
                            HStack{
                                Text("Apellidos:")
                                HStack{
                                    TextField("Apellidos", text: self.$datos.user.apellidos).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Teléfono
                            
                            HStack{
                                Text("Móvil:       ")
                                HStack{
                                    TextField("Móvil", text: self.$datos.user.movil).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Teléfono
                            
                            HStack{
                                Text("Teléfono:  ")
                                HStack{
                                    TextField("Teléfono", text: self.$datos.user.telefono).disabled(true)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
  
                            //Correo
                            VStack{
                                HStack{
                                    Text("Correo electrónico:")
                                    Spacer()
                                }.padding(.vertical,10)
                                
                                HStack{
                                    Text(self.datos.user.mail)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                            }
                            
                            //Código
                            VStack{
                                HStack{
                                    Text("Código:")
                                    Spacer()
                                }.padding(.top,10)
                                
                                HStack{
                                    TextField("Código", text: self.$datos.user.codigo).disabled(true)
                                        .autocapitalization(.none)
                                    Spacer()
                                }.padding(.horizontal).padding(.vertical,10)
                                    .background(Color.white).cornerRadius(10)
                                HStack{
                                    Text("*Únicamente para usuarios con movilidad")
                                        .font(.footnote)
                                    Spacer()
                                }
                                
                            }.padding(.bottom)
                            
                            
                            
                        }.padding().background(Color("Fondo").opacity(0.6)).cornerRadius(10)
                    }
                    
                    
                }.padding(.horizontal).background(Color.white)
                Spacer()
                
            } .navigationBarTitle("Detalle de Usuario")
                .navigationBarItems(trailing:
                    Button(action:{
                        if self.isEdit{
                            self.actualizaUsuario()
                        }else{
                            self.isEdit.toggle()
                        }
                        
                    }){
                        if self.isEdit{
                            Text("Guardar")
                        }else{
                            Text("Editar")
                        }
                        
                }).alert(isPresented: self.$showAlert){
                    Alert(title: Text("Actualizar usuario"), message: Text(self.textAlert), dismissButton: .default(Text("Aceptar"), action:{
                        self.isEdit.toggle()
                        //self.show.toggle()
                        
                    }))
            }

    }
}

struct UserDetailView_Previews: PreviewProvider {
    static var previews: some View {
        UserDetailView(datos: GetUser(user:""))
    }
}
