//
//  UsuarioView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 25/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct UsuarioView: View {
    @Binding var show: Bool
    @Binding var showMenu: Bool
    @State private var showNew:Bool=false
    @State private var showDetail:Bool=false
    
    @ObservedObject var datos = GetUsers()
    
    let adminMail = UserDefaults.standard.object(forKey: "UserMail") as! String
    
    var body: some View {
        NavigationView{
            ZStack(alignment: .bottomTrailing){
                
                VStack {
                    
                    Divider().padding(.horizontal)
                    
                    List{
                        ForEach (self.datos.users){ user in
                            if user.mail != self.adminMail{ //mostramos todos los usuarios menos el registrado actualmente
                                NavigationLink(destination: UserDetailView(datos:GetUser(user: user.mail))){
                                    VStack{
                                        HStack{
                                            Text("\(user.nombre) "+"\(user.apellidos)").bold()
                                            Spacer()
                                        }.padding(.bottom,7)
                                        HStack{
                                            Text(user.mail)
                                            Spacer()
                                            if user.isAdmin{
                                                Text("Administrador").foregroundColor(.orange)
                                            }else{
                                                Text("Usuario").foregroundColor(.green)
                                            }
                                            
                                        }
                                        
                                    }
                                }
                            }
                            
                        }
                        
                        
                        
                    }
                }
                VStack{
                   
                        Button(action:{
                            self.showNew.toggle()
                        }){
                            Image(systemName: "plus.circle.fill")
                                .resizable()
                                .frame(width: 60, height: 60)
                                .padding(.trailing,10)
                        }.sheet(isPresented: self.$showNew){
                            NewUserView(show: self.$showNew)
                    }
                }.padding(.bottom,50).padding(.trailing)
            }
            .navigationBarTitle("Usuarios")
            .navigationBarItems(leading:
                Button(action:{
                    self.showMenu.toggle()
                    self.show.toggle()
                    
                }){
                    HStack{
                        
                        Image(systemName: "chevron.left")
                            .resizable()
                            .frame(width: 10, height: 15)
                        Text("Salir").padding(.leading,-5)
                        Spacer()
                    }
                    
                })
            
        }.navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
    
    
}

struct UsuarioView_Previews: PreviewProvider {
    static var previews: some View {
        UsuarioView(show: .constant(false), showMenu: .constant(false))
    }
}
