//
//  CalendarView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 06/05/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI

struct CalendarView: View {
    
    @Binding var isPresented: Bool
    @ObservedObject var rkManager: RKManager
    
    private var monthFormat: DateFormatter{
        let format = DateFormatter()
               format.timeStyle = .none
               format.dateFormat = "MMM yy"
               return format
    }
    
    var body: some View {
        Group {
            ZStack(alignment: .top){
                RKMonth(isPresented: self.$isPresented,rkManager: self.rkManager, isOnlyMonth: true, monthOffset: self.rkManager.indexToday).padding(.vertical).background(Color("Fondo").opacity(0.4))
                HStack{
                    if self.rkManager.indexToday > 0{
                        Button(action:{
                            self.rkManager.indexToday -= 1
                        }){
                            Image(systemName: "chevron.left")
                                .resizable()
                                .frame(width: 15, height: 20)
                            .foregroundColor(.black)
                        }.padding(.leading,30)
                    }
                    Spacer()
                    if self.rkManager.indexToday < self.numberOfMonths(){
                        Button(action:{
                            self.rkManager.indexToday += 1
                        }){
                            Image(systemName: "chevron.right")
                                .resizable()
                                .frame(width: 15, height: 20).font(.title)
                            .foregroundColor(.black)
                        }.padding(.trailing,30)
                    }
                }.padding(.top).padding(.bottom,10).background(Color("Fondo").opacity(0.6))
                
            }
        }
    }
//    func monthDuration() -> DateInterval{
//        let calendar = Calendar.current
//        guard let interval = calendar.dateInterval(of: .month, for: self.rkManager.selectedDate) else { return DateInterval()}
//        return interval
//    }
    func numberOfMonths() -> Int {
        return rkManager.calendar.dateComponents([.month], from: rkManager.minimumDate, to: RKMaximumDateMonthLastDay()).month! + 1
    }
    
    func RKMaximumDateMonthLastDay() -> Date {
        var components = rkManager.calendar.dateComponents([.year, .month, .day], from: rkManager.maximumDate)
        components.month! += 1
        components.day = 0
        
        return rkManager.calendar.date(from: components)!
    }
}

#if DEBUG
struct CalendarView_Previews : PreviewProvider {
    static var previews: some View {
        Group {
            RKViewController(isPresented: .constant(false), rkManager: RKManager(calendar: Calendar.current, minimumDate: Date(), maximumDate: Date().addingTimeInterval(60*60*24*365), mode: 0))
            RKViewController(isPresented: .constant(false), rkManager: RKManager(calendar: Calendar.current, minimumDate: Date(), maximumDate: Date().addingTimeInterval(60*60*24*32), mode: 0))
                .environment(\.colorScheme, .dark)
                .environment(\.layoutDirection, .rightToLeft)
        }
    }
}
#endif
