//
//  GeneradorQRView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 04/05/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import FirebaseFirestore

struct GeneradorQRView: View {
    
    @State private var code: String = ""
    @State private var textAlert: String = ""
    @State private var showAlert: Bool = false
    @State private var updateHour: Date = Date()
    @State private var contador: Int = 0
    @State private var intervalo: Int = 15
    
    @Binding var show: Bool
    @Binding var showMenu: Bool
    
    private let timerGenerador = Timer.publish(every: 1, on: .main, in: .common).autoconnect()
    private let empresa: String = UserDefaults.standard.object(forKey: "Empresa") as! String
    private let empresaId: String = UserDefaults.standard.object(forKey: "EmpresaID") as! String
    
    private var timeFormat:DateFormatter{
        let format = DateFormatter()
        format.dateStyle = .none
        format.dateFormat = "HH:mm"
        return format
    }
    
    //Función que retorna un código aleatorio
    func generaCode() -> String{
        let base = ["a","b","c","d","e","f","g","h","I","J","K","L","M","N","O","P","Q","0","1","2","3","4","5","6","7","8","9"]
        var code: String = ""
        var i = 0
        while i < 10 {
            code = code + base.randomElement()!
            i+=1
        }
        return code
    }
    //función que actualiza el código para el fichaje de la empresa
    private func actualizaCodeEmpresa(){
        
        let db = Firestore.firestore()
        let campos : [String: Any] = ["code":self.code]
        db.collection("empresas").document(self.empresaId).updateData(campos){(error) in
            if error != nil{
                self.textAlert = "¡Error al actualizar código!"
                self.showAlert.toggle()
                //print(error!.localizedDescription)
            }
        }
        
    }
    
    //Función que genera un código QR a partir de un String
    private func generaQRCode(code:String)->Data{
        let filter = CIFilter(name: "CIQRCodeGenerator")
        let data = code.data(using: .ascii, allowLossyConversion: false)
        filter?.setValue(data, forKey: "inputMessage")
        let qrCode = filter?.outputImage
        let uiimage = UIImage(ciImage: qrCode!)
        
        return uiimage.pngData()!
    }
    
    
    var body: some View {
         NavigationView{
               VStack{
                   HStack{
                       HStack{
                           Spacer()
                           
                           Picker(selection: self.$intervalo, label: Text("")){
                               Text("15 min.").tag(15)
                               Text("30 min.").tag(30)
                               Text("60 min.").tag(60)
                               
                           }.pickerStyle(SegmentedPickerStyle())
                           Spacer()
                       }
                   }.padding(.top,5)
                   Text("Actualizaciones cada \(self.intervalo) minutos.").padding(.top)
                   Spacer()
                   Image(uiImage: UIImage(data: self.generaQRCode(code: self.code))!)
                       .resizable()
                       .frame(width: 150, height: 150, alignment: .center)
                   Spacer()
                   Text("Última actualización a las \(self.updateHour, formatter: self.timeFormat)").padding(.bottom)
                  
               }
               .navigationBarTitle("\(self.empresa)", displayMode: .inline)
                   .navigationBarItems(leading:
                       Button(action:{
                           self.timerGenerador.upstream.connect().cancel()
                           self.showMenu.toggle()
                           self.show.toggle()
                       }){
                           Text("Salir")
                       })
                   
         }.onReceive(self.timerGenerador){_ in
            //print(self.contador)
            if self.contador == 0{
                self.code = self.generaCode()
                self.actualizaCodeEmpresa()
                self.updateHour = Date()
                //print(self.code)
                self.contador += 1
            }else{
                self.contador += 1
                if self.contador == self.intervalo*60 {
                    self.contador = 0
                }
            }
            
         }.alert(isPresented: self.$showAlert){
            Alert(title: Text("Códigos QR"), message: Text("\(self.textAlert)"), dismissButton: .default(Text("Aceptar"), action:{
                self.timerGenerador.upstream.connect().cancel()
                self.showMenu.toggle()
                self.show.toggle()
            }))
         }
         .navigationBarTitle("")
         .navigationBarHidden(true)
    }
}

struct GeneradorQRView_Previews: PreviewProvider {
    static var previews: some View {
        GeneradorQRView(show: .constant(false), showMenu: .constant(false))
    }
}
