//
//  LectorView.swift
//  ControlWork
//
//  Created by Edu Perianes Lázaro on 23/03/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import SwiftUI
import CodeScanner

struct LectorView: View {
    
    @Binding var show: Bool
    @Binding var isStarted: Bool
    
    @State private var showAlert: Bool = false
    
    @EnvironmentObject var today: Jornada
    @ObservedObject var QR = GetCompanyCode()
    
    var body: some View {
        
        ZStack(alignment: .topTrailing){
            CodeScannerView(codeTypes: [.qr], simulatedData: "@eperianes", completion: self.handleScan).edgesIgnoringSafeArea(.vertical)
            Image("qr").resizable()
                .frame(width: UIScreen.main.bounds.width*1.2, height: UIScreen.main.bounds.height*1.1)
                .opacity(0.4)
                .edgesIgnoringSafeArea(.vertical)
            Button(action:{
                self.show.toggle()
            }){
                Image(systemName: "multiply")
                    .resizable()
                    .frame(width: 25, height: 25)
                    .foregroundColor(.black)
                    .padding(.trailing,70).padding(.top,90)
            }
        }.alert(isPresented: self.$showAlert){
            Alert(title: Text("Scanner"), message: Text("El código no se corresponde con el de su empresa"), dismissButton: .default(Text("Aceptar"), action: {
                self.show.toggle()
            }))
        }
       
            .navigationBarTitle("")
            .navigationBarHidden(true)
        
    }
    
    //Funcion para recoger el retorno del escaneo
    func handleScan(result: Result<String, CodeScannerView.ScanError>) {
        switch result {
        case .success(let code):
            if code.isEqual(self.QR.code){
                if self.isStarted{
                    self.today.finalizarDia(isGPS: false)
                    self.show.toggle()
                }else{
                    self.today.empezarDia(isGPS: false)
                    self.show.toggle()
                }
                
            }else{
                print(code)
                print(self.QR.code)
                self.showAlert.toggle()
               
            }
        case .failure(let error):
            print(error.localizedDescription)
        }
    }
}


struct LectorView_Previews: PreviewProvider {
    static var previews: some View {
        LectorView(show:.constant(true), isStarted: .constant(false))
    }
}
