//
//  ControlWorkTests.swift
//  ControlWorkTests
//
//  Created by Edu Perianes Lázaro on 10/05/2020.
//  Copyright © 2020 Edu Perianes Lázaro. All rights reserved.
//

import XCTest
import CoreLocation
@testable import ControlWork
@testable import FirebaseAuth
@testable import FirebaseFirestore


class ControlWorkTests: XCTestCase {
    
    //Test para la obtención de la localización
    func testAtualizacionLocalizacion() {
      let locations: [CLLocation] = [CLLocation(latitude: 12, longitude: 10)]
      
      let vista = GetLocalizacion()
      
      vista.locationManager(CLLocationManager(), didUpdateLocations: locations)
      
        XCTAssertEqual(12, vista.latitude)
        XCTAssertEqual(10, vista.longitude)
        
    }
    //Prueba de generación de cadenas de 10 carácteres para generar los códigos QR
    func testGeneradorCodigoQR(){
        let vista = GeneradorQRView(show: .constant(true), showMenu: .constant(false))
        let code = vista.generaCode()
        
        XCTAssertNotNil(code)
        XCTAssertEqual(10, code.count)
        
    }
    
    //Prueba de generación de cadenas de 6 carácteres para generar los password de usuario
    func testGeneradorContraseñaUser(){
        let vista = NewUserView(show: .constant(false))
        let password = vista.generaPassword()
        
        XCTAssertNotNil(password)
        XCTAssertEqual(6, password.count)
        
    }
    
    //Prueba de obtención de un string con la fecha actual formateada para los anuncios
    func testObtenFechaAnuncio(){
        let vista = AnuncioView(datos: Anuncio(id: "", titulo: "", usuario: "", fecha: Date(), prioridad: 0, anuncio: ""))
        var dateFormat: DateFormatter{
            let format = DateFormatter()
            format.dateFormat = "dd/MM/yyyy HH:mm"
            return format
        }
        let fecha = vista.obtenFecha()
        let date = dateFormat.string(from: Date())
        
        XCTAssertNotNil(fecha)
        XCTAssertEqual(16, fecha.count)
        XCTAssertEqual(date, fecha)
        
    }
    
    //Prueba de obtención de un string la diferencia de tiempo entre dos fechas en formato 0:00 horas o 0:00:00 horas
    func testObtenerDiferenciaEntreFechas(){
        let vista = Jornada()
        var dateFormat: DateFormatter{
            let format = DateFormatter()
            format.dateFormat = "dd/MM/yyyy HH:mm"
            return format
        }
        var fecha1 = dateFormat.date(from: "10/05/2020 20:00")
        var fecha2 = dateFormat.date(from: "10/05/2020 20:05")
        var diferencia = vista.obtenDiferencia(desde: fecha1!, hasta: fecha2!, full: false, isDescanso: false)
        
        XCTAssertNotNil(diferencia)
        XCTAssertEqual(4, diferencia.count)
        XCTAssertEqual("0:05", diferencia)
        
        fecha1 = dateFormat.date(from: "10/05/2020 20:00")
        fecha2 = dateFormat.date(from: "10/05/2020 20:30")
        diferencia = vista.obtenDiferencia(desde: fecha1!, hasta: fecha2!, full: true, isDescanso: false)
        
        XCTAssertNotNil(diferencia)
        XCTAssertEqual(7, diferencia.count)
        XCTAssertEqual("0:30:00", diferencia)
        
    }
    
    //Prueba de obtención de un string con la diferencia de tiempo entre las horas trabajadas y de descanso en formato 0:00 horas o 0:00:00 horas
    func testObtenerTotalTrabajado(){
        let vista = Jornada()
        var dateFormat: DateFormatter{
            let format = DateFormatter()
            format.dateFormat = "dd/MM/yyyy HH:mm"
            return format
        }
        vista.inicio = dateFormat.date(from: "10/05/2020 20:00")!
        vista.final = dateFormat.date(from: "10/05/2020 20:30")!
        vista.tiempoDescanso = 60*5
        
        
        var diferencia = vista.obtenTotalTrabajado(full: false)
        
        XCTAssertNotNil(diferencia)
        XCTAssertEqual(4, diferencia.count)
        XCTAssertEqual("0:25", diferencia)
        
        diferencia = vista.obtenTotalTrabajado(full: true)
        
        XCTAssertNotNil(diferencia)
        XCTAssertEqual(7, diferencia.count)
        XCTAssertEqual("0:25:00", diferencia)
        
    }
    
    //Prueba de la función para la obtención del año de un proyecto
    func testObtenerAñoDeProyecto(){
        let vista = ProyectosView()
        var dateFormat: DateFormatter{
            let format = DateFormatter()
            format.dateFormat = "dd/MM/yyyy HH:mm"
            return format
        }
        var fecha = dateFormat.date(from: "10/05/2020 20:00")
        var año = vista.getYear(date: fecha!)
        
        XCTAssertNotNil(año)
        XCTAssertEqual("2020", año)
        
        fecha = dateFormat.date(from: "10/05/2025 20:00")
        año = vista.getYear(date: fecha!)
        
        XCTAssertNotNil(año)
        XCTAssertEqual("2025", año)
        
        fecha = dateFormat.date(from: "10/05/2030 20:00")
        año = vista.getYear(date: fecha!)
        
        XCTAssertNotNil(año)
        XCTAssertEqual("2030", año)
        
    }
    //Test para probar la autenticación en Firebase
    func testAutenticacion() {
        //Expectación para test asíncrono
        let expectation = self.expectation(description: "autenticado")
        Auth.auth().signIn(withEmail: "edu@pruebas.com", password: "111111") { user, error in // User returned not nil
            XCTAssertNotNil(user)
            XCTAssertNil(error)
            XCTAssertEqual("edu@pruebas.com", user?.user.email)
            
            expectation.fulfill()
        }
        waitForExpectations(timeout: 5, handler: nil)
        //Sign Out
        try! Auth.auth().signOut()
        
    }
    
    //Test de prueba de escritura, actualización y borrado de información en la base de datos (añadimos un evento en una empresa de prueba)
    func testEscribirActualizarYBorrarEnBaseDeDatos() {
        //Expectación para test asíncrono
        let expectation = self.expectation(description: "Hecho!")
        let vista = NewAgenda(empresaID: "aATgTlnPnAretTx7mm9U", show: .constant(true), evento: "Prueba", inicio: Date(), fin: Date(), observaciones: "")
        vista.guardaEvento{ (documento,error) in

            XCTAssertNotNil(documento!.documentID)
            XCTAssertEqual(20, documento!.documentID.count)
            XCTAssertNil(error)
            
            self.ActualizarDatosBD(docId: documento!.documentID)
            self.EliminarDatosBD(docId: documento!.documentID)
            
            expectation.fulfill()
        }
        //Esperamos la espectación durante 5 segundos
        waitForExpectations(timeout: 5, handler: nil)
    }
    
    //Funcion para probar la actualización de datos en la BD
    func ActualizarDatosBD(docId: String) {
        
        let vista = EditAgendaView(show: .constant(true), evento: Evento(id: docId, inicio: Date(), fin: Date(), usuario: "", evento: "EventoUpdate", observaciones: ""), empresaID: "aATgTlnPnAretTx7mm9U")
        vista.actualizaEvento{ (error) in
            XCTAssertNil(error)
        }
       
    }
    //Funcion para probar la eliminación de datos en la BD
    func EliminarDatosBD(docId: String) {
        
        let vista = EditAgendaView(show: .constant(true), evento: Evento(id: docId, inicio: Date(), fin: Date(), usuario: "", evento: "EventoUpdate", observaciones: ""), empresaID: "aATgTlnPnAretTx7mm9U")
        vista.eliminaEvento{ (error) in
            XCTAssertNil(error)
        }
    }

}

